/****************************************************************************
** Meta object code from reading C++ file 'SettingsDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Gui/SettingsDialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SettingsDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Gui16FavoriteTagsPageE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::FavoriteTagsPage::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui16FavoriteTagsPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::FavoriteTagsPage",
        "saved",
        "",
        "widgetsUpdated",
        "updateWidgets",
        "moveTagBy",
        "offset",
        "addButtonClicked",
        "editButtonClicked",
        "deleteButtonClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widgetsUpdated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateWidgets'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveTagBy'
        QtMocHelpers::SlotData<void(const int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'addButtonClicked'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editButtonClicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteButtonClicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FavoriteTagsPage, qt_meta_tag_ZN3Gui16FavoriteTagsPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::FavoriteTagsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui16FavoriteTagsPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui16FavoriteTagsPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui16FavoriteTagsPageE_t>.metaTypes,
    nullptr
} };

void Gui::FavoriteTagsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FavoriteTagsPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saved(); break;
        case 1: _t->widgetsUpdated(); break;
        case 2: _t->updateWidgets(); break;
        case 3: _t->moveTagBy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->addButtonClicked(); break;
        case 5: _t->editButtonClicked(); break;
        case 6: _t->deleteButtonClicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FavoriteTagsPage::*)()>(_a, &FavoriteTagsPage::saved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FavoriteTagsPage::*)()>(_a, &FavoriteTagsPage::widgetsUpdated, 1))
            return;
    }
}

const QMetaObject *Gui::FavoriteTagsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::FavoriteTagsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui16FavoriteTagsPageE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui_FavoriteTagsPage"))
        return static_cast< Ui_FavoriteTagsPage*>(this);
    if (!strcmp(_clname, "ConfigurationWidgetInterface"))
        return static_cast< ConfigurationWidgetInterface*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int Gui::FavoriteTagsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Gui::FavoriteTagsPage::saved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gui::FavoriteTagsPage::widgetsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Gui11GeneralPageE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::GeneralPage::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui11GeneralPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::GeneralPage",
        "saved",
        "",
        "reloadPasswords",
        "widgetsUpdated",
        "updateWidgets",
        "moveIdentityUp",
        "moveIdentityDown",
        "addButtonClicked",
        "editButtonClicked",
        "deleteButtonClicked",
        "passwordPluginChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reloadPasswords'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widgetsUpdated'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateWidgets'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveIdentityUp'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveIdentityDown'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addButtonClicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editButtonClicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteButtonClicked'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'passwordPluginChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GeneralPage, qt_meta_tag_ZN3Gui11GeneralPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::GeneralPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui11GeneralPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui11GeneralPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui11GeneralPageE_t>.metaTypes,
    nullptr
} };

void Gui::GeneralPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GeneralPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saved(); break;
        case 1: _t->reloadPasswords(); break;
        case 2: _t->widgetsUpdated(); break;
        case 3: _t->updateWidgets(); break;
        case 4: _t->moveIdentityUp(); break;
        case 5: _t->moveIdentityDown(); break;
        case 6: _t->addButtonClicked(); break;
        case 7: _t->editButtonClicked(); break;
        case 8: _t->deleteButtonClicked(); break;
        case 9: _t->passwordPluginChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GeneralPage::*)()>(_a, &GeneralPage::saved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeneralPage::*)()>(_a, &GeneralPage::reloadPasswords, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeneralPage::*)()>(_a, &GeneralPage::widgetsUpdated, 2))
            return;
    }
}

const QMetaObject *Gui::GeneralPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::GeneralPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui11GeneralPageE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui_GeneralPage"))
        return static_cast< Ui_GeneralPage*>(this);
    if (!strcmp(_clname, "ConfigurationWidgetInterface"))
        return static_cast< ConfigurationWidgetInterface*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int Gui::GeneralPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Gui::GeneralPage::saved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gui::GeneralPage::reloadPasswords()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Gui::GeneralPage::widgetsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Gui12EditIdentityE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::EditIdentity::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui12EditIdentityE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::EditIdentity",
        "saved",
        "",
        "widgetsUpdated",
        "enableButton",
        "onReject"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widgetsUpdated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableButton'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onReject'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditIdentity, qt_meta_tag_ZN3Gui12EditIdentityE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::EditIdentity::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui12EditIdentityE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui12EditIdentityE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui12EditIdentityE_t>.metaTypes,
    nullptr
} };

void Gui::EditIdentity::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditIdentity *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saved(); break;
        case 1: _t->widgetsUpdated(); break;
        case 2: _t->enableButton(); break;
        case 3: _t->onReject(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditIdentity::*)()>(_a, &EditIdentity::saved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditIdentity::*)()>(_a, &EditIdentity::widgetsUpdated, 1))
            return;
    }
}

const QMetaObject *Gui::EditIdentity::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::EditIdentity::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui12EditIdentityE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui_EditIdentity"))
        return static_cast< Ui_EditIdentity*>(this);
    return QDialog::qt_metacast(_clname);
}

int Gui::EditIdentity::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Gui::EditIdentity::saved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gui::EditIdentity::widgetsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Gui15EditFavoriteTagE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::EditFavoriteTag::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui15EditFavoriteTagE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::EditFavoriteTag",
        "saved",
        "",
        "widgetsUpdated",
        "tryEnableButton",
        "onAccept",
        "onReject",
        "colorButtonClick"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widgetsUpdated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tryEnableButton'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onAccept'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onReject'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'colorButtonClick'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditFavoriteTag, qt_meta_tag_ZN3Gui15EditFavoriteTagE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::EditFavoriteTag::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui15EditFavoriteTagE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui15EditFavoriteTagE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui15EditFavoriteTagE_t>.metaTypes,
    nullptr
} };

void Gui::EditFavoriteTag::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditFavoriteTag *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saved(); break;
        case 1: _t->widgetsUpdated(); break;
        case 2: _t->tryEnableButton(); break;
        case 3: _t->onAccept(); break;
        case 4: _t->onReject(); break;
        case 5: _t->colorButtonClick(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditFavoriteTag::*)()>(_a, &EditFavoriteTag::saved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditFavoriteTag::*)()>(_a, &EditFavoriteTag::widgetsUpdated, 1))
            return;
    }
}

const QMetaObject *Gui::EditFavoriteTag::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::EditFavoriteTag::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui15EditFavoriteTagE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui_EditFavoriteTag"))
        return static_cast< Ui_EditFavoriteTag*>(this);
    return QDialog::qt_metacast(_clname);
}

int Gui::EditFavoriteTag::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Gui::EditFavoriteTag::saved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gui::EditFavoriteTag::widgetsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Gui12OutgoingPageE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::OutgoingPage::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui12OutgoingPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::OutgoingPage",
        "saved",
        "",
        "widgetsUpdated",
        "slotSetSubmissionMethod",
        "updateWidgets",
        "slotSetPassword",
        "showPortWarning",
        "warning",
        "setPortByText",
        "text"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widgetsUpdated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetSubmissionMethod'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWidgets'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetPassword'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showPortWarning'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'setPortByText'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OutgoingPage, qt_meta_tag_ZN3Gui12OutgoingPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::OutgoingPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui12OutgoingPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui12OutgoingPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui12OutgoingPageE_t>.metaTypes,
    nullptr
} };

void Gui::OutgoingPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OutgoingPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saved(); break;
        case 1: _t->widgetsUpdated(); break;
        case 2: _t->slotSetSubmissionMethod(); break;
        case 3: _t->updateWidgets(); break;
        case 4: _t->slotSetPassword(); break;
        case 5: _t->showPortWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->setPortByText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OutgoingPage::*)()>(_a, &OutgoingPage::saved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutgoingPage::*)()>(_a, &OutgoingPage::widgetsUpdated, 1))
            return;
    }
}

const QMetaObject *Gui::OutgoingPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::OutgoingPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui12OutgoingPageE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui_OutgoingPage"))
        return static_cast< Ui_OutgoingPage*>(this);
    if (!strcmp(_clname, "ConfigurationWidgetInterface"))
        return static_cast< ConfigurationWidgetInterface*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int Gui::OutgoingPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Gui::OutgoingPage::saved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gui::OutgoingPage::widgetsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Gui8ImapPageE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::ImapPage::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui8ImapPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::ImapPage",
        "saved",
        "",
        "widgetsUpdated",
        "updateWidgets",
        "maybeShowPortWarning",
        "changePort",
        "slotSetPassword"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widgetsUpdated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateWidgets'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'maybeShowPortWarning'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changePort'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetPassword'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImapPage, qt_meta_tag_ZN3Gui8ImapPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::ImapPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui8ImapPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui8ImapPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui8ImapPageE_t>.metaTypes,
    nullptr
} };

void Gui::ImapPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImapPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saved(); break;
        case 1: _t->widgetsUpdated(); break;
        case 2: _t->updateWidgets(); break;
        case 3: _t->maybeShowPortWarning(); break;
        case 4: _t->changePort(); break;
        case 5: _t->slotSetPassword(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImapPage::*)()>(_a, &ImapPage::saved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImapPage::*)()>(_a, &ImapPage::widgetsUpdated, 1))
            return;
    }
}

const QMetaObject *Gui::ImapPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::ImapPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui8ImapPageE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui_ImapPage"))
        return static_cast< Ui_ImapPage*>(this);
    if (!strcmp(_clname, "ConfigurationWidgetInterface"))
        return static_cast< ConfigurationWidgetInterface*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int Gui::ImapPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Gui::ImapPage::saved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gui::ImapPage::widgetsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Gui9CachePageE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::CachePage::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui9CachePageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::CachePage",
        "saved",
        "",
        "widgetsUpdated",
        "updateWidgets"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widgetsUpdated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateWidgets'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CachePage, qt_meta_tag_ZN3Gui9CachePageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::CachePage::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui9CachePageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui9CachePageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui9CachePageE_t>.metaTypes,
    nullptr
} };

void Gui::CachePage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CachePage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saved(); break;
        case 1: _t->widgetsUpdated(); break;
        case 2: _t->updateWidgets(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CachePage::*)()>(_a, &CachePage::saved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CachePage::*)()>(_a, &CachePage::widgetsUpdated, 1))
            return;
    }
}

const QMetaObject *Gui::CachePage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::CachePage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui9CachePageE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui_CachePage"))
        return static_cast< Ui_CachePage*>(this);
    if (!strcmp(_clname, "ConfigurationWidgetInterface"))
        return static_cast< ConfigurationWidgetInterface*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int Gui::CachePage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Gui::CachePage::saved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gui::CachePage::widgetsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Gui14SettingsDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::SettingsDialog::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui14SettingsDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::SettingsDialog",
        "reloadPasswordsRequested",
        "",
        "accept",
        "reject",
        "adjustSizeToScrollAreas",
        "slotAccept"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reloadPasswordsRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reject'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'adjustSizeToScrollAreas'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAccept'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SettingsDialog, qt_meta_tag_ZN3Gui14SettingsDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::SettingsDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui14SettingsDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui14SettingsDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui14SettingsDialogE_t>.metaTypes,
    nullptr
} };

void Gui::SettingsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reloadPasswordsRequested(); break;
        case 1: _t->accept(); break;
        case 2: _t->reject(); break;
        case 3: _t->adjustSizeToScrollAreas(); break;
        case 4: _t->slotAccept(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SettingsDialog::*)()>(_a, &SettingsDialog::reloadPasswordsRequested, 0))
            return;
    }
}

const QMetaObject *Gui::SettingsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::SettingsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui14SettingsDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Gui::SettingsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Gui::SettingsDialog::reloadPasswordsRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
