/****************************************************************************
** Meta object code from reading C++ file 'QtKeyChainPassword.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Plugins/QtKeyChain/QtKeyChainPassword.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'QtKeyChainPassword.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Plugins21QtKeyChainPasswordJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Plugins::QtKeyChainPasswordJob::qt_create_metaobjectdata<qt_meta_tag_ZN7Plugins21QtKeyChainPasswordJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plugins::QtKeyChainPasswordJob",
        "doStart",
        "",
        "doStop",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doStart'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doStop'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'result'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QtKeyChainPasswordJob, qt_meta_tag_ZN7Plugins21QtKeyChainPasswordJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plugins::QtKeyChainPasswordJob::staticMetaObject = { {
    QMetaObject::SuperData::link<PasswordJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins21QtKeyChainPasswordJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins21QtKeyChainPasswordJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Plugins21QtKeyChainPasswordJobE_t>.metaTypes,
    nullptr
} };

void Plugins::QtKeyChainPasswordJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QtKeyChainPasswordJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doStart(); break;
        case 1: _t->doStop(); break;
        case 2: _t->result(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Plugins::QtKeyChainPasswordJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plugins::QtKeyChainPasswordJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins21QtKeyChainPasswordJobE_t>.strings))
        return static_cast<void*>(this);
    return PasswordJob::qt_metacast(_clname);
}

int Plugins::QtKeyChainPasswordJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PasswordJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Plugins18QtKeyChainPasswordE_t {};
} // unnamed namespace

template <> constexpr inline auto Plugins::QtKeyChainPassword::qt_create_metaobjectdata<qt_meta_tag_ZN7Plugins18QtKeyChainPasswordE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plugins::QtKeyChainPassword",
        "requestPassword",
        "Plugins::PasswordJob*",
        "",
        "accountId",
        "accountType",
        "storePassword",
        "password",
        "deletePassword"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'requestPassword'
        QtMocHelpers::SlotData<Plugins::PasswordJob *(const QString &, const QString &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'storePassword'
        QtMocHelpers::SlotData<Plugins::PasswordJob *(const QString &, const QString &, const QString &)>(6, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'deletePassword'
        QtMocHelpers::SlotData<Plugins::PasswordJob *(const QString &, const QString &)>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QtKeyChainPassword, qt_meta_tag_ZN7Plugins18QtKeyChainPasswordE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plugins::QtKeyChainPassword::staticMetaObject = { {
    QMetaObject::SuperData::link<PasswordPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins18QtKeyChainPasswordE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins18QtKeyChainPasswordE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Plugins18QtKeyChainPasswordE_t>.metaTypes,
    nullptr
} };

void Plugins::QtKeyChainPassword::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QtKeyChainPassword *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Plugins::PasswordJob* _r = _t->requestPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Plugins::PasswordJob**>(_a[0]) = std::move(_r); }  break;
        case 1: { Plugins::PasswordJob* _r = _t->storePassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Plugins::PasswordJob**>(_a[0]) = std::move(_r); }  break;
        case 2: { Plugins::PasswordJob* _r = _t->deletePassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Plugins::PasswordJob**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Plugins::QtKeyChainPassword::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plugins::QtKeyChainPassword::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins18QtKeyChainPasswordE_t>.strings))
        return static_cast<void*>(this);
    return PasswordPlugin::qt_metacast(_clname);
}

int Plugins::QtKeyChainPassword::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PasswordPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN39trojita_plugin_QtKeyChainPasswordPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto trojita_plugin_QtKeyChainPasswordPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN39trojita_plugin_QtKeyChainPasswordPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "trojita_plugin_QtKeyChainPasswordPlugin"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<trojita_plugin_QtKeyChainPasswordPlugin, qt_meta_tag_ZN39trojita_plugin_QtKeyChainPasswordPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject trojita_plugin_QtKeyChainPasswordPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39trojita_plugin_QtKeyChainPasswordPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39trojita_plugin_QtKeyChainPasswordPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN39trojita_plugin_QtKeyChainPasswordPluginE_t>.metaTypes,
    nullptr
} };

void trojita_plugin_QtKeyChainPasswordPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<trojita_plugin_QtKeyChainPasswordPlugin *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *trojita_plugin_QtKeyChainPasswordPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *trojita_plugin_QtKeyChainPasswordPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39trojita_plugin_QtKeyChainPasswordPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Plugins::PasswordPluginInterface"))
        return static_cast< Plugins::PasswordPluginInterface*>(this);
    if (!strcmp(_clname, "PasswordPluginInterface"))
        return static_cast< Plugins::PasswordPluginInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int trojita_plugin_QtKeyChainPasswordPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_trojita_plugin_QtKeyChainPasswordPlugin[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x2e,  'n',  'e',  't',  '.',  'f', 
    'l',  'a',  's',  'k',  'a',  '.',  't',  'r', 
    'o',  'j',  'i',  't',  'a',  '.',  'p',  'l', 
    'u',  'g',  'i',  'n',  's',  '.',  'p',  'a', 
    's',  's',  'w',  'o',  'r',  'd',  '.',  'q', 
    't',  'k',  'e',  'y',  'c',  'h',  'a',  'i', 
    'n', 
    // "className"
    0x03,  0x78,  0x27,  't',  'r',  'o',  'j',  'i', 
    't',  'a',  '_',  'p',  'l',  'u',  'g',  'i', 
    'n',  '_',  'Q',  't',  'K',  'e',  'y',  'C', 
    'h',  'a',  'i',  'n',  'P',  'a',  's',  's', 
    'w',  'o',  'r',  'd',  'P',  'l',  'u',  'g', 
    'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(trojita_plugin_QtKeyChainPasswordPlugin, trojita_plugin_QtKeyChainPasswordPlugin, qt_pluginMetaDataV2_trojita_plugin_QtKeyChainPasswordPlugin)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_trojita_plugin_QtKeyChainPasswordPlugin[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x2e,  'n',  'e',  't',  '.',  'f', 
    'l',  'a',  's',  'k',  'a',  '.',  't',  'r', 
    'o',  'j',  'i',  't',  'a',  '.',  'p',  'l', 
    'u',  'g',  'i',  'n',  's',  '.',  'p',  'a', 
    's',  's',  'w',  'o',  'r',  'd',  '.',  'q', 
    't',  'k',  'e',  'y',  'c',  'h',  'a',  'i', 
    'n', 
    // "className"
    0x03,  0x78,  0x27,  't',  'r',  'o',  'j',  'i', 
    't',  'a',  '_',  'p',  'l',  'u',  'g',  'i', 
    'n',  '_',  'Q',  't',  'K',  'e',  'y',  'C', 
    'h',  'a',  'i',  'n',  'P',  'a',  's',  's', 
    'w',  'o',  'r',  'd',  'P',  'l',  'u',  'g', 
    'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(trojita_plugin_QtKeyChainPasswordPlugin, trojita_plugin_QtKeyChainPasswordPlugin)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
