/****************************************************************************
** Meta object code from reading C++ file 'OneMessageModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Imap/Model/OneMessageModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OneMessageModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Imap7Mailbox15OneMessageModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Imap::Mailbox::OneMessageModel::qt_create_metaobjectdata<qt_meta_tag_ZN4Imap7Mailbox15OneMessageModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Imap::Mailbox::OneMessageModel",
        "envelopeChanged",
        "",
        "flagsChanged",
        "mainPartUrlChanged",
        "handleModelDataChanged",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "setMessage",
        "mailbox",
        "uid",
        "subject",
        "date",
        "receivedDate",
        "from",
        "QVariantList",
        "to",
        "cc",
        "bcc",
        "sender",
        "replyTo",
        "inReplyTo",
        "messageId",
        "isMarkedDeleted",
        "isMarkedRead",
        "isMarkedForwarded",
        "isMarkedReplied",
        "isMarkedRecent",
        "isMarkedFlagged",
        "isMarkedJunk",
        "isMarkedNotJunk",
        "mainPartUrl",
        "QUrl",
        "attachmentsModel",
        "hasValidIndex",
        "mainPartModelIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'envelopeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'flagsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mainPartUrlChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleModelDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Method 'setMessage'
        QtMocHelpers::MethodData<void(const QString &, const uint)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::UInt, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'subject'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'date'
        QtMocHelpers::PropertyData<QDateTime>(13, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 0),
        // property 'receivedDate'
        QtMocHelpers::PropertyData<QDateTime>(14, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 0),
        // property 'from'
        QtMocHelpers::PropertyData<QVariantList>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'to'
        QtMocHelpers::PropertyData<QVariantList>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'cc'
        QtMocHelpers::PropertyData<QVariantList>(18, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'bcc'
        QtMocHelpers::PropertyData<QVariantList>(19, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'sender'
        QtMocHelpers::PropertyData<QVariantList>(20, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'replyTo'
        QtMocHelpers::PropertyData<QVariantList>(21, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'inReplyTo'
        QtMocHelpers::PropertyData<QByteArray>(22, QMetaType::QByteArray, QMC::DefaultPropertyFlags, 0),
        // property 'messageId'
        QtMocHelpers::PropertyData<QByteArray>(23, QMetaType::QByteArray, QMC::DefaultPropertyFlags, 0),
        // property 'isMarkedDeleted'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'isMarkedRead'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'isMarkedForwarded'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isMarkedReplied'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isMarkedRecent'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isMarkedFlagged'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isMarkedJunk'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isMarkedNotJunk'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'mainPartUrl'
        QtMocHelpers::PropertyData<QUrl>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'attachmentsModel'
        QtMocHelpers::PropertyData<QObject*>(34, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 2),
        // property 'hasValidIndex'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'mainPartModelIndex'
        QtMocHelpers::PropertyData<QModelIndex>(36, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OneMessageModel, qt_meta_tag_ZN4Imap7Mailbox15OneMessageModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Imap::Mailbox::OneMessageModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox15OneMessageModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox15OneMessageModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Imap7Mailbox15OneMessageModelE_t>.metaTypes,
    nullptr
} };

void Imap::Mailbox::OneMessageModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OneMessageModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->envelopeChanged(); break;
        case 1: _t->flagsChanged(); break;
        case 2: _t->mainPartUrlChanged(); break;
        case 3: _t->handleModelDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 4: _t->setMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OneMessageModel::*)()>(_a, &OneMessageModel::envelopeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OneMessageModel::*)()>(_a, &OneMessageModel::flagsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OneMessageModel::*)()>(_a, &OneMessageModel::mainPartUrlChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->subject(); break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->date(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->receivedDate(); break;
        case 3: *reinterpret_cast<QVariantList*>(_v) = _t->from(); break;
        case 4: *reinterpret_cast<QVariantList*>(_v) = _t->to(); break;
        case 5: *reinterpret_cast<QVariantList*>(_v) = _t->cc(); break;
        case 6: *reinterpret_cast<QVariantList*>(_v) = _t->bcc(); break;
        case 7: *reinterpret_cast<QVariantList*>(_v) = _t->sender(); break;
        case 8: *reinterpret_cast<QVariantList*>(_v) = _t->replyTo(); break;
        case 9: *reinterpret_cast<QByteArray*>(_v) = _t->inReplyTo(); break;
        case 10: *reinterpret_cast<QByteArray*>(_v) = _t->messageId(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isMarkedDeleted(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isMarkedRead(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isMarkedForwarded(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->isMarkedReplied(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isMarkedRecent(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isMarkedFlagged(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isMarkedJunk(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isMarkedNotJunk(); break;
        case 19: *reinterpret_cast<QUrl*>(_v) = _t->mainPartUrl(); break;
        case 20: *reinterpret_cast<QObject**>(_v) = _t->attachmentsModel(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->hasValidIndex(); break;
        case 22: *reinterpret_cast<QModelIndex*>(_v) = _t->mainPartModelIndex(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 11: _t->setMarkedDeleted(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setMarkedRead(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Imap::Mailbox::OneMessageModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Imap::Mailbox::OneMessageModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox15OneMessageModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Imap::Mailbox::OneMessageModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void Imap::Mailbox::OneMessageModel::envelopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Imap::Mailbox::OneMessageModel::flagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Imap::Mailbox::OneMessageModel::mainPartUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
