/****************************************************************************
** Meta object code from reading C++ file 'qwwsmtpclient.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/qwwsmtpclient/qwwsmtpclient.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwwsmtpclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QwwSmtpClientE_t {};
} // unnamed namespace

template <> constexpr inline auto QwwSmtpClient::qt_create_metaobjectdata<qt_meta_tag_ZN13QwwSmtpClientE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QwwSmtpClient",
        "done",
        "",
        "connected",
        "disconnected",
        "stateChanged",
        "QwwSmtpClient::State",
        "commandFinished",
        "error",
        "commandStarted",
        "tlsStarted",
        "authenticated",
        "rawCommandReply",
        "code",
        "details",
        "sslErrors",
        "QList<QSslError>",
        "socketError",
        "QAbstractSocket::SocketError",
        "err",
        "message",
        "logReceived",
        "data",
        "logSent",
        "disconnectFromHost",
        "startTls",
        "ignoreSslErrors",
        "onConnected",
        "onDisconnected",
        "onError",
        "_q_readFromSocket",
        "_q_encrypted",
        "State",
        "Disconnected",
        "Connecting",
        "Connected",
        "TLSRequested",
        "Authenticating",
        "Sending",
        "Disconnecting",
        "Options",
        "Option",
        "NoOptions",
        "StartTlsOption",
        "SizeOption",
        "PipeliningOption",
        "EightBitMimeOption",
        "AuthOption",
        "AuthModes",
        "AuthMode",
        "AuthNone",
        "AuthAny",
        "AuthPlain",
        "AuthLogin"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'done'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'connected'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disconnected'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(QwwSmtpClient::State)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'commandFinished'
        QtMocHelpers::SignalData<void(int, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Bool, 8 },
        }}),
        // Signal 'commandStarted'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'tlsStarted'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authenticated'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rawCommandReply'
        QtMocHelpers::SignalData<void(int, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'sslErrors'
        QtMocHelpers::SignalData<void(const QList<QSslError> &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Signal 'socketError'
        QtMocHelpers::SignalData<void(QAbstractSocket::SocketError, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'logReceived'
        QtMocHelpers::SignalData<void(const QByteArray &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 22 },
        }}),
        // Signal 'logSent'
        QtMocHelpers::SignalData<void(const QByteArray &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 22 },
        }}),
        // Slot 'disconnectFromHost'
        QtMocHelpers::SlotData<int()>(24, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'startTls'
        QtMocHelpers::SlotData<int()>(25, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'ignoreSslErrors'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onConnected'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDisconnected'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onError'
        QtMocHelpers::SlotData<void(QAbstractSocket::SocketError)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Slot '_q_readFromSocket'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_encrypted'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(32, 32, QMC::EnumFlags{}).add({
            {   33, State::Disconnected },
            {   34, State::Connecting },
            {   35, State::Connected },
            {   36, State::TLSRequested },
            {   37, State::Authenticating },
            {   38, State::Sending },
            {   39, State::Disconnecting },
        }),
        // flag 'Options'
        QtMocHelpers::EnumData<Options>(40, 41, QMC::EnumIsFlag).add({
            {   42, Option::NoOptions },
            {   43, Option::StartTlsOption },
            {   44, Option::SizeOption },
            {   45, Option::PipeliningOption },
            {   46, Option::EightBitMimeOption },
            {   47, Option::AuthOption },
        }),
        // flag 'AuthModes'
        QtMocHelpers::EnumData<AuthModes>(48, 49, QMC::EnumIsFlag).add({
            {   50, AuthMode::AuthNone },
            {   51, AuthMode::AuthAny },
            {   52, AuthMode::AuthPlain },
            {   53, AuthMode::AuthLogin },
        }),
    };
    return QtMocHelpers::metaObjectData<QwwSmtpClient, qt_meta_tag_ZN13QwwSmtpClientE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QwwSmtpClient::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QwwSmtpClientE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QwwSmtpClientE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QwwSmtpClientE_t>.metaTypes,
    nullptr
} };

void QwwSmtpClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QwwSmtpClient *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->done((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->connected(); break;
        case 2: _t->disconnected(); break;
        case 3: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<QwwSmtpClient::State>>(_a[1]))); break;
        case 4: _t->commandFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->commandStarted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->tlsStarted(); break;
        case 7: _t->authenticated(); break;
        case 8: _t->rawCommandReply((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->sslErrors((*reinterpret_cast<std::add_pointer_t<QList<QSslError>>>(_a[1]))); break;
        case 10: _t->socketError((*reinterpret_cast<std::add_pointer_t<QAbstractSocket::SocketError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->logReceived((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 12: _t->logSent((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 13: { int _r = _t->disconnectFromHost();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->startTls();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->ignoreSslErrors(); break;
        case 16: _t->d->onConnected(); break;
        case 17: _t->d->onDisconnected(); break;
        case 18: _t->d->onError((*reinterpret_cast<std::add_pointer_t<QAbstractSocket::SocketError>>(_a[1]))); break;
        case 19: _t->d->_q_readFromSocket(); break;
        case 20: _t->d->_q_encrypted(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QSslError> >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSocket::SocketError >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSocket::SocketError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)(bool )>(_a, &QwwSmtpClient::done, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)()>(_a, &QwwSmtpClient::connected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)()>(_a, &QwwSmtpClient::disconnected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)(QwwSmtpClient::State )>(_a, &QwwSmtpClient::stateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)(int , bool )>(_a, &QwwSmtpClient::commandFinished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)(int )>(_a, &QwwSmtpClient::commandStarted, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)()>(_a, &QwwSmtpClient::tlsStarted, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)()>(_a, &QwwSmtpClient::authenticated, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)(int , const QString & )>(_a, &QwwSmtpClient::rawCommandReply, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)(const QList<QSslError> & )>(_a, &QwwSmtpClient::sslErrors, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)(QAbstractSocket::SocketError , const QString & )>(_a, &QwwSmtpClient::socketError, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)(const QByteArray & )>(_a, &QwwSmtpClient::logReceived, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QwwSmtpClient::*)(const QByteArray & )>(_a, &QwwSmtpClient::logSent, 12))
            return;
    }
}

const QMetaObject *QwwSmtpClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QwwSmtpClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QwwSmtpClientE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QwwSmtpClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void QwwSmtpClient::done(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QwwSmtpClient::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QwwSmtpClient::disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QwwSmtpClient::stateChanged(QwwSmtpClient::State _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QwwSmtpClient::commandFinished(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void QwwSmtpClient::commandStarted(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QwwSmtpClient::tlsStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QwwSmtpClient::authenticated()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QwwSmtpClient::rawCommandReply(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void QwwSmtpClient::sslErrors(const QList<QSslError> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void QwwSmtpClient::socketError(QAbstractSocket::SocketError _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void QwwSmtpClient::logReceived(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void QwwSmtpClient::logSent(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
