/****************************************************************************
** Meta object code from reading C++ file 'FakeMSA.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/MSA/FakeMSA.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FakeMSA.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3MSA4FakeE_t {};
} // unnamed namespace

template <> constexpr inline auto MSA::Fake::qt_create_metaobjectdata<qt_meta_tag_ZN3MSA4FakeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MSA::Fake",
        "cancel",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Fake, qt_meta_tag_ZN3MSA4FakeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MSA::Fake::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractMSA::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA4FakeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA4FakeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3MSA4FakeE_t>.metaTypes,
    nullptr
} };

void MSA::Fake::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Fake *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cancel(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *MSA::Fake::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MSA::Fake::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA4FakeE_t>.strings))
        return static_cast<void*>(this);
    return AbstractMSA::qt_metacast(_clname);
}

int MSA::Fake::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractMSA::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN3MSA11FakeFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto MSA::FakeFactory::qt_create_metaobjectdata<qt_meta_tag_ZN3MSA11FakeFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MSA::FakeFactory",
        "requestedSending",
        "",
        "from",
        "QList<QByteArray>",
        "to",
        "data",
        "requestedBurlSending",
        "imapUrl",
        "requestedCancelling",
        "connecting",
        "sending",
        "sent",
        "error",
        "message",
        "progressMax",
        "max",
        "progress",
        "num",
        "doEmitConnecting",
        "doEmitSending",
        "doEmitSent",
        "doEmitError",
        "doEmitProgressMax",
        "doEmitProgress"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestedSending'
        QtMocHelpers::SignalData<void(const QByteArray &, const QList<QByteArray> &, const QByteArray &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 3 }, { 0x80000000 | 4, 5 }, { QMetaType::QByteArray, 6 },
        }}),
        // Signal 'requestedBurlSending'
        QtMocHelpers::SignalData<void(const QByteArray &, const QList<QByteArray> &, const QByteArray &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 3 }, { 0x80000000 | 4, 5 }, { QMetaType::QByteArray, 8 },
        }}),
        // Signal 'requestedCancelling'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connecting'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sending'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sent'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'progressMax'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'progress'
        QtMocHelpers::SignalData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'doEmitConnecting'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doEmitSending'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doEmitSent'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doEmitError'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'doEmitProgressMax'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'doEmitProgress'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FakeFactory, qt_meta_tag_ZN3MSA11FakeFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MSA::FakeFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA11FakeFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA11FakeFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3MSA11FakeFactoryE_t>.metaTypes,
    nullptr
} };

void MSA::FakeFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FakeFactory *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestedSending((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3]))); break;
        case 1: _t->requestedBurlSending((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3]))); break;
        case 2: _t->requestedCancelling(); break;
        case 3: _t->connecting(); break;
        case 4: _t->sending(); break;
        case 5: _t->sent(); break;
        case 6: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->progressMax((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->progress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->doEmitConnecting(); break;
        case 10: _t->doEmitSending(); break;
        case 11: _t->doEmitSent(); break;
        case 12: _t->doEmitError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->doEmitProgressMax((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->doEmitProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FakeFactory::*)(const QByteArray & , const QList<QByteArray> & , const QByteArray & )>(_a, &FakeFactory::requestedSending, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeFactory::*)(const QByteArray & , const QList<QByteArray> & , const QByteArray & )>(_a, &FakeFactory::requestedBurlSending, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeFactory::*)()>(_a, &FakeFactory::requestedCancelling, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeFactory::*)()>(_a, &FakeFactory::connecting, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeFactory::*)()>(_a, &FakeFactory::sending, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeFactory::*)()>(_a, &FakeFactory::sent, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeFactory::*)(const QString & )>(_a, &FakeFactory::error, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeFactory::*)(int )>(_a, &FakeFactory::progressMax, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeFactory::*)(int )>(_a, &FakeFactory::progress, 8))
            return;
    }
}

const QMetaObject *MSA::FakeFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MSA::FakeFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA11FakeFactoryE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "MSAFactory"))
        return static_cast< MSAFactory*>(this);
    return QObject::qt_metacast(_clname);
}

int MSA::FakeFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void MSA::FakeFactory::requestedSending(const QByteArray & _t1, const QList<QByteArray> & _t2, const QByteArray & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void MSA::FakeFactory::requestedBurlSending(const QByteArray & _t1, const QList<QByteArray> & _t2, const QByteArray & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void MSA::FakeFactory::requestedCancelling()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MSA::FakeFactory::connecting()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MSA::FakeFactory::sending()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MSA::FakeFactory::sent()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MSA::FakeFactory::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MSA::FakeFactory::progressMax(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void MSA::FakeFactory::progress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
