/****************************************************************************
** Meta object code from reading C++ file 'ImapAccess.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Imap/Model/ImapAccess.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ImapAccess.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Imap10ImapAccessE_t {};
} // unnamed namespace

template <> constexpr inline auto Imap::ImapAccess::qt_create_metaobjectdata<qt_meta_tag_ZN4Imap10ImapAccessE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Imap::ImapAccess",
        "serverChanged",
        "",
        "portChanged",
        "usernameChanged",
        "connMethodChanged",
        "modelsChanged",
        "checkSslPolicy",
        "cacheError",
        "message",
        "numberRefreshIntervalChanged",
        "alertReceived",
        "imapError",
        "networkError",
        "onCacheError",
        "slotLogged",
        "parserId",
        "Common::LogMessage",
        "slotSslErrors",
        "QList<QSslCertificate>",
        "sslCertificateChain",
        "QList<QSslError>",
        "sslErrors",
        "reloadConfiguration",
        "onRequireStartTlsInFuture",
        "desiredNetworkPolicyChanged",
        "Imap::Mailbox::NetworkPolicy",
        "policy",
        "doConnect",
        "openMessage",
        "mailbox",
        "uid",
        "setSslPolicy",
        "accept",
        "forgetSslCertificate",
        "nukeCache",
        "mailboxListShortMailboxName",
        "mailboxListMailboxName",
        "deproxifiedIndex",
        "QModelIndex",
        "index",
        "markMessageDeleted",
        "marked",
        "isConfigured",
        "imapModel",
        "mailboxModel",
        "msgListModel",
        "threadingMsgListModel",
        "visibleTasksModel",
        "oneMessageModel",
        "networkWatcher",
        "msgQNAM",
        "passwordWatcher",
        "UiUtils::PasswordWatcher*",
        "server",
        "port",
        "username",
        "sslMode",
        "sslInfoTitle",
        "sslInfoMessage",
        "numberRefreshInterval"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'serverChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'portChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usernameChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connMethodChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'checkSslPolicy'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cacheError'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'numberRefreshIntervalChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alertReceived'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'imapError'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'networkError'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'onCacheError'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'slotLogged'
        QtMocHelpers::SlotData<void(uint, const Common::LogMessage &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 16 }, { 0x80000000 | 17, 9 },
        }}),
        // Slot 'slotSslErrors'
        QtMocHelpers::SlotData<void(const QList<QSslCertificate> &, const QList<QSslError> &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'reloadConfiguration'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onRequireStartTlsInFuture'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'desiredNetworkPolicyChanged'
        QtMocHelpers::SlotData<void(const Imap::Mailbox::NetworkPolicy)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Method 'doConnect'
        QtMocHelpers::MethodData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openMessage'
        QtMocHelpers::MethodData<void(const QString &, const uint)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::UInt, 31 },
        }}),
        // Method 'setSslPolicy'
        QtMocHelpers::MethodData<void(bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Method 'forgetSslCertificate'
        QtMocHelpers::MethodData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'nukeCache'
        QtMocHelpers::MethodData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'mailboxListShortMailboxName'
        QtMocHelpers::MethodData<QString() const>(36, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'mailboxListMailboxName'
        QtMocHelpers::MethodData<QString() const>(37, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'deproxifiedIndex'
        QtMocHelpers::MethodData<QModelIndex(const QModelIndex)>(38, 2, QMC::AccessPublic, 0x80000000 | 39, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Method 'markMessageDeleted'
        QtMocHelpers::MethodData<void(const QModelIndex &, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 9 }, { QMetaType::Bool, 42 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isConfigured'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'imapModel'
        QtMocHelpers::PropertyData<QObject*>(44, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'mailboxModel'
        QtMocHelpers::PropertyData<QObject*>(45, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'msgListModel'
        QtMocHelpers::PropertyData<QObject*>(46, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'threadingMsgListModel'
        QtMocHelpers::PropertyData<QObject*>(47, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'visibleTasksModel'
        QtMocHelpers::PropertyData<QObject*>(48, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'oneMessageModel'
        QtMocHelpers::PropertyData<QObject*>(49, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'networkWatcher'
        QtMocHelpers::PropertyData<QObject*>(50, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'msgQNAM'
        QtMocHelpers::PropertyData<QObject*>(51, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'passwordWatcher'
        QtMocHelpers::PropertyData<UiUtils::PasswordWatcher*>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'server'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'port'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'username'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'sslMode'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'sslInfoTitle'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'sslInfoMessage'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'numberRefreshInterval'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImapAccess, qt_meta_tag_ZN4Imap10ImapAccessE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Imap::ImapAccess::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap10ImapAccessE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap10ImapAccessE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Imap10ImapAccessE_t>.metaTypes,
    nullptr
} };

void Imap::ImapAccess::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImapAccess *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->serverChanged(); break;
        case 1: _t->portChanged(); break;
        case 2: _t->usernameChanged(); break;
        case 3: _t->connMethodChanged(); break;
        case 4: _t->modelsChanged(); break;
        case 5: _t->checkSslPolicy(); break;
        case 6: _t->cacheError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->numberRefreshIntervalChanged(); break;
        case 8: _t->alertReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->imapError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->networkError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->onCacheError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->slotLogged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Common::LogMessage>>(_a[2]))); break;
        case 13: _t->slotSslErrors((*reinterpret_cast<std::add_pointer_t<QList<QSslCertificate>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QSslError>>>(_a[2]))); break;
        case 14: _t->reloadConfiguration(); break;
        case 15: _t->onRequireStartTlsInFuture(); break;
        case 16: _t->desiredNetworkPolicyChanged((*reinterpret_cast<std::add_pointer_t<Imap::Mailbox::NetworkPolicy>>(_a[1]))); break;
        case 17: _t->doConnect(); break;
        case 18: _t->openMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 19: _t->setSslPolicy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->forgetSslCertificate(); break;
        case 21: _t->nukeCache(); break;
        case 22: { QString _r = _t->mailboxListShortMailboxName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: { QString _r = _t->mailboxListMailboxName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: { QModelIndex _r = _t->deproxifiedIndex((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->markMessageDeleted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QSslCertificate> >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QSslError> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImapAccess::*)()>(_a, &ImapAccess::serverChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImapAccess::*)()>(_a, &ImapAccess::portChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImapAccess::*)()>(_a, &ImapAccess::usernameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImapAccess::*)()>(_a, &ImapAccess::connMethodChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImapAccess::*)()>(_a, &ImapAccess::modelsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImapAccess::*)()>(_a, &ImapAccess::checkSslPolicy, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImapAccess::*)(const QString & )>(_a, &ImapAccess::cacheError, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImapAccess::*)()>(_a, &ImapAccess::numberRefreshIntervalChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UiUtils::PasswordWatcher* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isConfigured(); break;
        case 1: *reinterpret_cast<QObject**>(_v) = _t->imapModel(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->mailboxModel(); break;
        case 3: *reinterpret_cast<QObject**>(_v) = _t->msgListModel(); break;
        case 4: *reinterpret_cast<QObject**>(_v) = _t->threadingMsgListModel(); break;
        case 5: *reinterpret_cast<QObject**>(_v) = _t->visibleTasksModel(); break;
        case 6: *reinterpret_cast<QObject**>(_v) = _t->oneMessageModel(); break;
        case 7: *reinterpret_cast<QObject**>(_v) = _t->networkWatcher(); break;
        case 8: *reinterpret_cast<QObject**>(_v) = _t->msgQNAM(); break;
        case 9: *reinterpret_cast<UiUtils::PasswordWatcher**>(_v) = _t->passwordWatcher(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->server(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->port(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->username(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->sslMode(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->sslInfoTitle(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->sslInfoMessage(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->numberRefreshInterval(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 10: _t->setServer(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setPort(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setUsername(*reinterpret_cast<QString*>(_v)); break;
        case 13: _t->setSslMode(*reinterpret_cast<QString*>(_v)); break;
        case 16: _t->setNumberRefreshInterval(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Imap::ImapAccess::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Imap::ImapAccess::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap10ImapAccessE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Imap::ImapAccess::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void Imap::ImapAccess::serverChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Imap::ImapAccess::portChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Imap::ImapAccess::usernameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Imap::ImapAccess::connMethodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Imap::ImapAccess::modelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Imap::ImapAccess::checkSslPolicy()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Imap::ImapAccess::cacheError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Imap::ImapAccess::numberRefreshIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
