/****************************************************************************
** Meta object code from reading C++ file 'AbookAddressbook.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Plugins/AbookAddressbook/AbookAddressbook.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbookAddressbook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16AbookAddressbookE_t {};
} // unnamed namespace

template <> constexpr inline auto AbookAddressbook::qt_create_metaobjectdata<qt_meta_tag_ZN16AbookAddressbookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbookAddressbook",
        "requestCompletion",
        "Plugins::AddressbookCompletionJob*",
        "",
        "input",
        "ignores",
        "max",
        "requestPrettyNamesForAddress",
        "Plugins::AddressbookNamesJob*",
        "email",
        "openAddressbookWindow",
        "openContactWindow",
        "displayName",
        "saveContacts",
        "readAbook",
        "update",
        "updateAbook",
        "scheduleAbookUpdate"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'requestCompletion'
        QtMocHelpers::SlotData<Plugins::AddressbookCompletionJob *(const QString &, const QStringList &, int)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QStringList, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'requestCompletion'
        QtMocHelpers::SlotData<Plugins::AddressbookCompletionJob *(const QString &, const QStringList &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QStringList, 5 },
        }}),
        // Slot 'requestCompletion'
        QtMocHelpers::SlotData<Plugins::AddressbookCompletionJob *(const QString &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'requestPrettyNamesForAddress'
        QtMocHelpers::SlotData<Plugins::AddressbookNamesJob *(const QString &)>(7, 3, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'openAddressbookWindow'
        QtMocHelpers::SlotData<void()>(10, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openContactWindow'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(11, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'saveContacts'
        QtMocHelpers::SlotData<void()>(13, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readAbook'
        QtMocHelpers::SlotData<void(bool)>(14, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'readAbook'
        QtMocHelpers::SlotData<void()>(14, 3, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'updateAbook'
        QtMocHelpers::SlotData<void()>(16, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scheduleAbookUpdate'
        QtMocHelpers::SlotData<void()>(17, 3, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbookAddressbook, qt_meta_tag_ZN16AbookAddressbookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbookAddressbook::staticMetaObject = { {
    QMetaObject::SuperData::link<AddressbookPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AbookAddressbookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AbookAddressbookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16AbookAddressbookE_t>.metaTypes,
    nullptr
} };

void AbookAddressbook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbookAddressbook *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Plugins::AddressbookCompletionJob* _r = _t->requestCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Plugins::AddressbookCompletionJob**>(_a[0]) = std::move(_r); }  break;
        case 1: { Plugins::AddressbookCompletionJob* _r = _t->requestCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Plugins::AddressbookCompletionJob**>(_a[0]) = std::move(_r); }  break;
        case 2: { Plugins::AddressbookCompletionJob* _r = _t->requestCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Plugins::AddressbookCompletionJob**>(_a[0]) = std::move(_r); }  break;
        case 3: { Plugins::AddressbookNamesJob* _r = _t->requestPrettyNamesForAddress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Plugins::AddressbookNamesJob**>(_a[0]) = std::move(_r); }  break;
        case 4: _t->openAddressbookWindow(); break;
        case 5: _t->openContactWindow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->saveContacts(); break;
        case 7: _t->readAbook((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->readAbook(); break;
        case 9: _t->updateAbook(); break;
        case 10: _t->scheduleAbookUpdate(); break;
        default: ;
        }
    }
}

const QMetaObject *AbookAddressbook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbookAddressbook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AbookAddressbookE_t>.strings))
        return static_cast<void*>(this);
    return AddressbookPlugin::qt_metacast(_clname);
}

int AbookAddressbook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AddressbookPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN37trojita_plugin_AbookAddressbookPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto trojita_plugin_AbookAddressbookPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN37trojita_plugin_AbookAddressbookPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "trojita_plugin_AbookAddressbookPlugin"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<trojita_plugin_AbookAddressbookPlugin, qt_meta_tag_ZN37trojita_plugin_AbookAddressbookPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject trojita_plugin_AbookAddressbookPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37trojita_plugin_AbookAddressbookPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37trojita_plugin_AbookAddressbookPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN37trojita_plugin_AbookAddressbookPluginE_t>.metaTypes,
    nullptr
} };

void trojita_plugin_AbookAddressbookPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<trojita_plugin_AbookAddressbookPlugin *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *trojita_plugin_AbookAddressbookPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *trojita_plugin_AbookAddressbookPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37trojita_plugin_AbookAddressbookPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "AddressbookPluginInterface"))
        return static_cast< AddressbookPluginInterface*>(this);
    if (!strcmp(_clname, "AddressbookPluginInterface"))
        return static_cast< Plugins::AddressbookPluginInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int trojita_plugin_AbookAddressbookPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_trojita_plugin_AbookAddressbookPlugin[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x37,  'n',  'e',  't',  '.',  'f', 
    'l',  'a',  's',  'k',  'a',  '.',  't',  'r', 
    'o',  'j',  'i',  't',  'a',  '.',  'p',  'l', 
    'u',  'g',  'i',  'n',  's',  '.',  'a',  'd', 
    'd',  'r',  'e',  's',  's',  'b',  'o',  'o', 
    'k',  '.',  'a',  'b',  'o',  'o',  'k',  'a', 
    'd',  'd',  'r',  'e',  's',  's',  'b',  'o', 
    'o',  'k', 
    // "className"
    0x03,  0x78,  0x25,  't',  'r',  'o',  'j',  'i', 
    't',  'a',  '_',  'p',  'l',  'u',  'g',  'i', 
    'n',  '_',  'A',  'b',  'o',  'o',  'k',  'A', 
    'd',  'd',  'r',  'e',  's',  's',  'b',  'o', 
    'o',  'k',  'P',  'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(trojita_plugin_AbookAddressbookPlugin, trojita_plugin_AbookAddressbookPlugin, qt_pluginMetaDataV2_trojita_plugin_AbookAddressbookPlugin)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_trojita_plugin_AbookAddressbookPlugin[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x37,  'n',  'e',  't',  '.',  'f', 
    'l',  'a',  's',  'k',  'a',  '.',  't',  'r', 
    'o',  'j',  'i',  't',  'a',  '.',  'p',  'l', 
    'u',  'g',  'i',  'n',  's',  '.',  'a',  'd', 
    'd',  'r',  'e',  's',  's',  'b',  'o',  'o', 
    'k',  '.',  'a',  'b',  'o',  'o',  'k',  'a', 
    'd',  'd',  'r',  'e',  's',  's',  'b',  'o', 
    'o',  'k', 
    // "className"
    0x03,  0x78,  0x25,  't',  'r',  'o',  'j',  'i', 
    't',  'a',  '_',  'p',  'l',  'u',  'g',  'i', 
    'n',  '_',  'A',  'b',  'o',  'o',  'k',  'A', 
    'd',  'd',  'r',  'e',  's',  's',  'b',  'o', 
    'o',  'k',  'P',  'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(trojita_plugin_AbookAddressbookPlugin, trojita_plugin_AbookAddressbookPlugin)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
