/****************************************************************************
** Meta object code from reading C++ file 'Model.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Imap/Model/Model.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Model.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Imap7Mailbox5ModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Imap::Mailbox::Model::qt_create_metaobjectdata<qt_meta_tag_ZN4Imap7Mailbox5ModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Imap::Mailbox::Model",
        "alertReceived",
        "",
        "message",
        "networkPolicyOffline",
        "networkPolicyExpensive",
        "networkPolicyOnline",
        "networkPolicyChanged",
        "networkError",
        "imapError",
        "authRequested",
        "authAttemptFailed",
        "needsSslDecision",
        "QList<QSslCertificate>",
        "certificates",
        "QList<QSslError>",
        "sslErrors",
        "requireStartTlsInFuture",
        "messageCountPossiblyChanged",
        "QModelIndex",
        "mailbox",
        "mailboxCreationSucceded",
        "mailboxCreationFailed",
        "mailboxDeletionSucceded",
        "mailboxDeletionFailed",
        "mailboxSyncFailed",
        "connectionStateChanged",
        "parserId",
        "Imap::ConnectionState",
        "state",
        "logParserFatalError",
        "parser",
        "exceptionClass",
        "line",
        "position",
        "mailboxSyncingProgress",
        "Imap::Mailbox::MailboxSyncingProgress",
        "mailboxFirstUnseenMessage",
        "maillbox",
        "threadingAvailable",
        "algorithm",
        "searchCriteria",
        "QList<Imap::Responses::ThreadingNode>",
        "mapping",
        "threadingFailed",
        "capabilitiesUpdated",
        "capabilities",
        "logged",
        "Common::LogMessage",
        "imapAuthErrorChanged",
        "error",
        "imapUserChanged",
        "imapPasswordChanged",
        "reloadMailboxList",
        "switchToMailbox",
        "mbox",
        "setSslPolicy",
        "sslChain",
        "proceed",
        "invalidateAllMessageCounts",
        "handleSocketStateChanged",
        "Imap::Parser*",
        "slotParserLineReceived",
        "slotParserLineSent",
        "slotTasksChanged",
        "slotTaskDying",
        "obj",
        "setImapAuthError",
        "responseReceived",
        "askForChildrenOfMailbox",
        "index",
        "Imap::Mailbox::CacheLoadingMode",
        "cacheMode",
        "askForMessagesInMailbox",
        "runReadyTasks",
        "imapUser",
        "imapPassword",
        "imapAuthError",
        "isNetworkAvailable",
        "isNetworkOnline"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'alertReceived'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'networkPolicyOffline'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'networkPolicyExpensive'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'networkPolicyOnline'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'networkPolicyChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'networkError'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'imapError'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'authRequested'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authAttemptFailed'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'needsSslDecision'
        QtMocHelpers::SignalData<void(const QList<QSslCertificate> &, const QList<QSslError> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Signal 'requireStartTlsInFuture'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'messageCountPossiblyChanged'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'mailboxCreationSucceded'
        QtMocHelpers::SignalData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'mailboxCreationFailed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 3 },
        }}),
        // Signal 'mailboxDeletionSucceded'
        QtMocHelpers::SignalData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'mailboxDeletionFailed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 3 },
        }}),
        // Signal 'mailboxSyncFailed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 3 },
        }}),
        // Signal 'connectionStateChanged'
        QtMocHelpers::SignalData<void(uint, Imap::ConnectionState)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Signal 'logParserFatalError'
        QtMocHelpers::SignalData<void(uint, const QString &, const QString &, const QByteArray &, int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 3 }, { QMetaType::QByteArray, 33 },
            { QMetaType::Int, 34 },
        }}),
        // Signal 'mailboxSyncingProgress'
        QtMocHelpers::SignalData<void(const QModelIndex &, Imap::Mailbox::MailboxSyncingProgress)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 36, 29 },
        }}),
        // Signal 'mailboxFirstUnseenMessage'
        QtMocHelpers::SignalData<void(const QModelIndex &, const QModelIndex &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 38 }, { 0x80000000 | 19, 3 },
        }}),
        // Signal 'threadingAvailable'
        QtMocHelpers::SignalData<void(const QModelIndex &, const QByteArray &, const QStringList &, const QVector<Imap::Responses::ThreadingNode> &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QByteArray, 40 }, { QMetaType::QStringList, 41 }, { 0x80000000 | 42, 43 },
        }}),
        // Signal 'threadingFailed'
        QtMocHelpers::SignalData<void(const QModelIndex &, const QByteArray &, const QStringList &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QByteArray, 40 }, { QMetaType::QStringList, 41 },
        }}),
        // Signal 'capabilitiesUpdated'
        QtMocHelpers::SignalData<void(const QStringList &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 46 },
        }}),
        // Signal 'logged'
        QtMocHelpers::SignalData<void(uint, const Common::LogMessage &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 27 }, { 0x80000000 | 48, 3 },
        }}),
        // Signal 'imapAuthErrorChanged'
        QtMocHelpers::SignalData<void(const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 50 },
        }}),
        // Signal 'imapUserChanged'
        QtMocHelpers::SignalData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imapPasswordChanged'
        QtMocHelpers::SignalData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadMailboxList'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchToMailbox'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 55 },
        }}),
        // Slot 'setSslPolicy'
        QtMocHelpers::SlotData<void(const QList<QSslCertificate> &, const QList<QSslError> &, bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 57 }, { 0x80000000 | 15, 16 }, { QMetaType::Bool, 58 },
        }}),
        // Slot 'invalidateAllMessageCounts'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleSocketStateChanged'
        QtMocHelpers::SlotData<void(Imap::Parser *, Imap::ConnectionState)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 61, 31 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'slotParserLineReceived'
        QtMocHelpers::SlotData<void(Imap::Parser *, const QByteArray &)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 61, 31 }, { QMetaType::QByteArray, 33 },
        }}),
        // Slot 'slotParserLineSent'
        QtMocHelpers::SlotData<void(Imap::Parser *, const QByteArray &)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 61, 31 }, { QMetaType::QByteArray, 33 },
        }}),
        // Slot 'slotTasksChanged'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTaskDying'
        QtMocHelpers::SlotData<void(QObject *)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 66 },
        }}),
        // Slot 'setImapAuthError'
        QtMocHelpers::SlotData<void(const QString &)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 50 },
        }}),
        // Slot 'responseReceived'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'responseReceived'
        QtMocHelpers::SlotData<void(Imap::Parser *)>(68, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 61, 31 },
        }}),
        // Slot 'askForChildrenOfMailbox'
        QtMocHelpers::SlotData<void(const QModelIndex &, const Imap::Mailbox::CacheLoadingMode)>(69, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 19, 70 }, { 0x80000000 | 71, 72 },
        }}),
        // Slot 'askForMessagesInMailbox'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(73, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 19, 70 },
        }}),
        // Slot 'runReadyTasks'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'imapUser'
        QtMocHelpers::PropertyData<QString>(75, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'imapPassword'
        QtMocHelpers::PropertyData<QString>(76, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 27),
        // property 'imapAuthError'
        QtMocHelpers::PropertyData<QString>(77, QMetaType::QString, QMC::DefaultPropertyFlags, 25),
        // property 'isNetworkAvailable'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'isNetworkOnline'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Model, qt_meta_tag_ZN4Imap7Mailbox5ModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Imap::Mailbox::Model::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox5ModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox5ModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Imap7Mailbox5ModelE_t>.metaTypes,
    nullptr
} };

void Imap::Mailbox::Model::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Model *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->alertReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->networkPolicyOffline(); break;
        case 2: _t->networkPolicyExpensive(); break;
        case 3: _t->networkPolicyOnline(); break;
        case 4: _t->networkPolicyChanged(); break;
        case 5: _t->networkError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->imapError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->authRequested(); break;
        case 8: _t->authAttemptFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->needsSslDecision((*reinterpret_cast<std::add_pointer_t<QList<QSslCertificate>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QSslError>>>(_a[2]))); break;
        case 10: _t->requireStartTlsInFuture(); break;
        case 11: _t->messageCountPossiblyChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 12: _t->mailboxCreationSucceded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->mailboxCreationFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->mailboxDeletionSucceded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->mailboxDeletionFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->mailboxSyncFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->connectionStateChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::ConnectionState>>(_a[2]))); break;
        case 18: _t->logParserFatalError((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 19: _t->mailboxSyncingProgress((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::Mailbox::MailboxSyncingProgress>>(_a[2]))); break;
        case 20: _t->mailboxFirstUnseenMessage((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 21: _t->threadingAvailable((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QList<Imap::Responses::ThreadingNode>>>(_a[4]))); break;
        case 22: _t->threadingFailed((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 23: _t->capabilitiesUpdated((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 24: _t->logged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Common::LogMessage>>(_a[2]))); break;
        case 25: _t->imapAuthErrorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->imapUserChanged(); break;
        case 27: _t->imapPasswordChanged(); break;
        case 28: _t->reloadMailboxList(); break;
        case 29: _t->switchToMailbox((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 30: _t->setSslPolicy((*reinterpret_cast<std::add_pointer_t<QList<QSslCertificate>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QSslError>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 31: _t->invalidateAllMessageCounts(); break;
        case 32: _t->handleSocketStateChanged((*reinterpret_cast<std::add_pointer_t<Imap::Parser*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::ConnectionState>>(_a[2]))); break;
        case 33: _t->slotParserLineReceived((*reinterpret_cast<std::add_pointer_t<Imap::Parser*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 34: _t->slotParserLineSent((*reinterpret_cast<std::add_pointer_t<Imap::Parser*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 35: _t->slotTasksChanged(); break;
        case 36: _t->slotTaskDying((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 37: _t->setImapAuthError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->responseReceived(); break;
        case 39: _t->responseReceived((*reinterpret_cast<std::add_pointer_t<Imap::Parser*>>(_a[1]))); break;
        case 40: _t->askForChildrenOfMailbox((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::Mailbox::CacheLoadingMode>>(_a[2]))); break;
        case 41: _t->askForMessagesInMailbox((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 42: _t->runReadyTasks(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Imap::Responses::ThreadingNode> >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Parser* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Parser* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Parser* >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Parser* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Mailbox::CacheLoadingMode >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & )>(_a, &Model::alertReceived, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)()>(_a, &Model::networkPolicyOffline, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)()>(_a, &Model::networkPolicyExpensive, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)()>(_a, &Model::networkPolicyOnline, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)()>(_a, &Model::networkPolicyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & )>(_a, &Model::networkError, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & )>(_a, &Model::imapError, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)()>(_a, &Model::authRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & )>(_a, &Model::authAttemptFailed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QList<QSslCertificate> & , const QList<QSslError> & )>(_a, &Model::needsSslDecision, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)()>(_a, &Model::requireStartTlsInFuture, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QModelIndex & )>(_a, &Model::messageCountPossiblyChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & )>(_a, &Model::mailboxCreationSucceded, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & , const QString & )>(_a, &Model::mailboxCreationFailed, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & )>(_a, &Model::mailboxDeletionSucceded, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & , const QString & )>(_a, &Model::mailboxDeletionFailed, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & , const QString & )>(_a, &Model::mailboxSyncFailed, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(uint , Imap::ConnectionState )>(_a, &Model::connectionStateChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(uint , const QString & , const QString & , const QByteArray & , int )>(_a, &Model::logParserFatalError, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QModelIndex & , Imap::Mailbox::MailboxSyncingProgress )>(_a, &Model::mailboxSyncingProgress, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QModelIndex & , const QModelIndex & )>(_a, &Model::mailboxFirstUnseenMessage, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QModelIndex & , const QByteArray & , const QStringList & , const QVector<Imap::Responses::ThreadingNode> & )>(_a, &Model::threadingAvailable, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QModelIndex & , const QByteArray & , const QStringList & )>(_a, &Model::threadingFailed, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QStringList & )>(_a, &Model::capabilitiesUpdated, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(uint , const Common::LogMessage & )>(_a, &Model::logged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)(const QString & )>(_a, &Model::imapAuthErrorChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)()>(_a, &Model::imapUserChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Model::*)()>(_a, &Model::imapPasswordChanged, 27))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->imapUser(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->imapPassword(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->imapAuthError(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isNetworkAvailable(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isNetworkOnline(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setImapUser(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setImapPassword(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 1: _t->unsetImapPassword(); break;
        default: break;
        }
    }
}

const QMetaObject *Imap::Mailbox::Model::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Imap::Mailbox::Model::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox5ModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int Imap::Mailbox::Model::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Imap::Mailbox::Model::alertReceived(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Imap::Mailbox::Model::networkPolicyOffline()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Imap::Mailbox::Model::networkPolicyExpensive()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Imap::Mailbox::Model::networkPolicyOnline()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Imap::Mailbox::Model::networkPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Imap::Mailbox::Model::networkError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Imap::Mailbox::Model::imapError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Imap::Mailbox::Model::authRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Imap::Mailbox::Model::authAttemptFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Imap::Mailbox::Model::needsSslDecision(const QList<QSslCertificate> & _t1, const QList<QSslError> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void Imap::Mailbox::Model::requireStartTlsInFuture()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Imap::Mailbox::Model::messageCountPossiblyChanged(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Imap::Mailbox::Model::mailboxCreationSucceded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Imap::Mailbox::Model::mailboxCreationFailed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void Imap::Mailbox::Model::mailboxDeletionSucceded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Imap::Mailbox::Model::mailboxDeletionFailed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void Imap::Mailbox::Model::mailboxSyncFailed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}

// SIGNAL 17
void Imap::Mailbox::Model::connectionStateChanged(uint _t1, Imap::ConnectionState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void Imap::Mailbox::Model::logParserFatalError(uint _t1, const QString & _t2, const QString & _t3, const QByteArray & _t4, int _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 19
void Imap::Mailbox::Model::mailboxSyncingProgress(const QModelIndex & _t1, Imap::Mailbox::MailboxSyncingProgress _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void Imap::Mailbox::Model::mailboxFirstUnseenMessage(const QModelIndex & _t1, const QModelIndex & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2);
}

// SIGNAL 21
void Imap::Mailbox::Model::threadingAvailable(const QModelIndex & _t1, const QByteArray & _t2, const QStringList & _t3, const QVector<Imap::Responses::ThreadingNode> & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 22
void Imap::Mailbox::Model::threadingFailed(const QModelIndex & _t1, const QByteArray & _t2, const QStringList & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2, _t3);
}

// SIGNAL 23
void Imap::Mailbox::Model::capabilitiesUpdated(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void Imap::Mailbox::Model::logged(uint _t1, const Common::LogMessage & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1, _t2);
}

// SIGNAL 25
void Imap::Mailbox::Model::imapAuthErrorChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void Imap::Mailbox::Model::imapUserChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void Imap::Mailbox::Model::imapPasswordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}
QT_WARNING_POP
