/****************************************************************************
** Meta object code from reading C++ file 'PasswordWatcher.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/UiUtils/PasswordWatcher.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PasswordWatcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7UiUtils15PasswordWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto UiUtils::PasswordWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN7UiUtils15PasswordWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UiUtils::PasswordWatcher",
        "backendMaybeChanged",
        "",
        "stateChanged",
        "readingFailed",
        "message",
        "savingFailed",
        "readingDone",
        "savingDone",
        "reloadPassword",
        "setPassword",
        "password",
        "passwordRetrieved",
        "passwordReadingFailed",
        "Plugins::PasswordJob::Error",
        "errorCode",
        "errorMessage",
        "passwordWritten",
        "passwordWritingFailed",
        "isStorageEncrypted",
        "isWaitingForPlugin",
        "isPluginAvailable",
        "progressMessage",
        "didReadOk",
        "didWriteOk"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'backendMaybeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readingFailed'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'savingFailed'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'readingDone'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'savingDone'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadPassword'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPassword'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'passwordRetrieved'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'passwordReadingFailed'
        QtMocHelpers::SlotData<void(const Plugins::PasswordJob::Error, const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'passwordWritten'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'passwordWritingFailed'
        QtMocHelpers::SlotData<void(const Plugins::PasswordJob::Error, const QString &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isStorageEncrypted'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'isWaitingForPlugin'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isPluginAvailable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'progressMessage'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'password'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'didReadOk'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'didWriteOk'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PasswordWatcher, qt_meta_tag_ZN7UiUtils15PasswordWatcherE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UiUtils::PasswordWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7UiUtils15PasswordWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7UiUtils15PasswordWatcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7UiUtils15PasswordWatcherE_t>.metaTypes,
    nullptr
} };

void UiUtils::PasswordWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PasswordWatcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->backendMaybeChanged(); break;
        case 1: _t->stateChanged(); break;
        case 2: _t->readingFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->savingFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->readingDone(); break;
        case 5: _t->savingDone(); break;
        case 6: _t->reloadPassword(); break;
        case 7: _t->setPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->passwordRetrieved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->passwordReadingFailed((*reinterpret_cast<std::add_pointer_t<Plugins::PasswordJob::Error>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->passwordWritten(); break;
        case 11: _t->passwordWritingFailed((*reinterpret_cast<std::add_pointer_t<Plugins::PasswordJob::Error>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PasswordWatcher::*)()>(_a, &PasswordWatcher::backendMaybeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordWatcher::*)()>(_a, &PasswordWatcher::stateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordWatcher::*)(const QString & )>(_a, &PasswordWatcher::readingFailed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordWatcher::*)(const QString & )>(_a, &PasswordWatcher::savingFailed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordWatcher::*)()>(_a, &PasswordWatcher::readingDone, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordWatcher::*)()>(_a, &PasswordWatcher::savingDone, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isStorageEncrypted(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isWaitingForPlugin(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isPluginAvailable(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->progressMessage(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->password(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->didReadOk(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->didWriteOk(); break;
        default: break;
        }
    }
}

const QMetaObject *UiUtils::PasswordWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UiUtils::PasswordWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7UiUtils15PasswordWatcherE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UiUtils::PasswordWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void UiUtils::PasswordWatcher::backendMaybeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UiUtils::PasswordWatcher::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UiUtils::PasswordWatcher::readingFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UiUtils::PasswordWatcher::savingFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UiUtils::PasswordWatcher::readingDone()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void UiUtils::PasswordWatcher::savingDone()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
