/****************************************************************************
** Meta object code from reading C++ file 'Account.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/MSA/Account.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Account.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3MSA7AccountE_t {};
} // unnamed namespace

template <> constexpr inline auto MSA::Account::qt_create_metaobjectdata<qt_meta_tag_ZN3MSA7AccountE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MSA::Account",
        "submissionMethodChanged",
        "",
        "serverChanged",
        "portChanged",
        "usernameChanged",
        "authenticateEnabledChanged",
        "reuseImapAuthenticationChanged",
        "pathToSendmailChanged",
        "saveToImapChanged",
        "sentMailboxNameChanged",
        "useBurlChanged",
        "showPortWarning",
        "message",
        "settingsSaved",
        "settingsRestored",
        "setSubmissionMethod",
        "MSA::Account::Method",
        "method",
        "setServer",
        "server",
        "setPort",
        "port",
        "setUsername",
        "username",
        "setAuthenticateEnabled",
        "auth",
        "setReuseImapAuthentication",
        "reuseImapAuth",
        "setPathToSendmail",
        "pathToSendmail",
        "setSaveToImap",
        "selected",
        "setSentMailboxName",
        "location",
        "setUseBurl",
        "maybeShowPortWarning",
        "saveSettings",
        "restoreSettings",
        "authenticateEnabled",
        "reuseImapAuthentication",
        "saveToImap",
        "sentMailboxName",
        "useBurl",
        "submissionMethod",
        "Method",
        "SMTP",
        "SSMTP",
        "SMTP_STARTTLS",
        "SENDMAIL",
        "IMAP_SENDMAIL"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'submissionMethodChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serverChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'portChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usernameChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authenticateEnabledChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reuseImapAuthenticationChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pathToSendmailChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saveToImapChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sentMailboxNameChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useBurlChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showPortWarning'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'settingsSaved'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'settingsRestored'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSubmissionMethod'
        QtMocHelpers::SlotData<void(const MSA::Account::Method)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setServer'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'setPort'
        QtMocHelpers::SlotData<void(const quint16)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 22 },
        }}),
        // Slot 'setUsername'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setAuthenticateEnabled'
        QtMocHelpers::SlotData<void(const bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setReuseImapAuthentication'
        QtMocHelpers::SlotData<void(const bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setPathToSendmail'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'setSaveToImap'
        QtMocHelpers::SlotData<void(const bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'setSentMailboxName'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Slot 'setUseBurl'
        QtMocHelpers::SlotData<void(const bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'maybeShowPortWarning'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'saveSettings'
        QtMocHelpers::MethodData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'restoreSettings'
        QtMocHelpers::MethodData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'server'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'port'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'username'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'authenticateEnabled'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'reuseImapAuthentication'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'pathToSendmail'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'saveToImap'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'sentMailboxName'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'useBurl'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'submissionMethod'
        QtMocHelpers::PropertyData<enum Method>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Method'
        QtMocHelpers::EnumData<enum Method>(45, 45, QMC::EnumIsScoped).add({
            {   46, Method::SMTP },
            {   47, Method::SSMTP },
            {   48, Method::SMTP_STARTTLS },
            {   49, Method::SENDMAIL },
            {   50, Method::IMAP_SENDMAIL },
        }),
    };
    return QtMocHelpers::metaObjectData<Account, qt_meta_tag_ZN3MSA7AccountE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MSA::Account::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA7AccountE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA7AccountE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3MSA7AccountE_t>.metaTypes,
    nullptr
} };

void MSA::Account::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Account *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->submissionMethodChanged(); break;
        case 1: _t->serverChanged(); break;
        case 2: _t->portChanged(); break;
        case 3: _t->usernameChanged(); break;
        case 4: _t->authenticateEnabledChanged(); break;
        case 5: _t->reuseImapAuthenticationChanged(); break;
        case 6: _t->pathToSendmailChanged(); break;
        case 7: _t->saveToImapChanged(); break;
        case 8: _t->sentMailboxNameChanged(); break;
        case 9: _t->useBurlChanged(); break;
        case 10: _t->showPortWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->settingsSaved(); break;
        case 12: _t->settingsRestored(); break;
        case 13: _t->setSubmissionMethod((*reinterpret_cast<std::add_pointer_t<MSA::Account::Method>>(_a[1]))); break;
        case 14: _t->setServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->setPort((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 16: _t->setUsername((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->setAuthenticateEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setReuseImapAuthentication((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setPathToSendmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->setSaveToImap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->setSentMailboxName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->setUseBurl((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->maybeShowPortWarning(); break;
        case 24: _t->saveSettings(); break;
        case 25: _t->restoreSettings(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::submissionMethodChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::serverChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::portChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::usernameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::authenticateEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::reuseImapAuthenticationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::pathToSendmailChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::saveToImapChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::sentMailboxNameChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::useBurlChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)(const QString & )>(_a, &Account::showPortWarning, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::settingsSaved, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Account::*)()>(_a, &Account::settingsRestored, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->server(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->port(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->username(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->authenticateEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->reuseImapAuthentication(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->pathToSendmail(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->saveToImap(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->sentMailboxName(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->useBurl(); break;
        case 9: *reinterpret_cast<enum Method*>(_v) = _t->submissionMethod(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setServer(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPort(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setUsername(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setAuthenticateEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setReuseImapAuthentication(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setPathToSendmail(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setSaveToImap(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setSentMailboxName(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setUseBurl(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setSubmissionMethod(*reinterpret_cast<enum Method*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MSA::Account::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MSA::Account::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA7AccountE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MSA::Account::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void MSA::Account::submissionMethodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MSA::Account::serverChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MSA::Account::portChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MSA::Account::usernameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MSA::Account::authenticateEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MSA::Account::reuseImapAuthenticationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MSA::Account::pathToSendmailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MSA::Account::saveToImapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MSA::Account::sentMailboxNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MSA::Account::useBurlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MSA::Account::showPortWarning(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void MSA::Account::settingsSaved()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void MSA::Account::settingsRestored()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
