/****************************************************************************
** Meta object code from reading C++ file 'Submission.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Composer/Submission.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Submission.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Composer10SubmissionE_t {};
} // unnamed namespace

template <> constexpr inline auto Composer::Submission::qt_create_metaobjectdata<qt_meta_tag_ZN8Composer10SubmissionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Composer::Submission",
        "progressMin",
        "",
        "min",
        "progressMax",
        "max",
        "progress",
        "updateStatusMessage",
        "message",
        "failed",
        "succeeded",
        "passwordRequested",
        "user",
        "host",
        "gotPassword",
        "password",
        "canceled",
        "logged",
        "Common::LogKind",
        "kind",
        "source",
        "setPassword",
        "cancelPassword",
        "gotError",
        "error",
        "sent",
        "slotAppendUidKnown",
        "uidValidity",
        "uid",
        "slotGenUrlAuthReceived",
        "url",
        "slotAppendSucceeded",
        "slotAppendFailed",
        "onUpdatingFlagsOfReplyingToSucceded",
        "onUpdatingFlagsOfReplyingToFailed",
        "onUpdatingFlagsOfForwardingSucceeded",
        "onUpdatingFlagsOfForwardingFailed",
        "slotMessageDataAvailable",
        "slotAskForUrl",
        "slotInvokeMsaNow",
        "onMsaProgressMaxChanged",
        "onMsaProgressCurrentChanged",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progressMin'
        QtMocHelpers::SignalData<void(const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'progressMax'
        QtMocHelpers::SignalData<void(const int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'progress'
        QtMocHelpers::SignalData<void(const int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'updateStatusMessage'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'succeeded'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordRequested'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'gotPassword'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'canceled'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logged'
        QtMocHelpers::SignalData<void(const Common::LogKind, const QString &, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'setPassword'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'cancelPassword'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotError'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'sent'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAppendUidKnown'
        QtMocHelpers::SlotData<void(const uint, const uint)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 27 }, { QMetaType::UInt, 28 },
        }}),
        // Slot 'slotGenUrlAuthReceived'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'slotAppendSucceeded'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAppendFailed'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'onUpdatingFlagsOfReplyingToSucceded'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUpdatingFlagsOfReplyingToFailed'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUpdatingFlagsOfForwardingSucceeded'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUpdatingFlagsOfForwardingFailed'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMessageDataAvailable'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAskForUrl'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInvokeMsaNow'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMsaProgressMaxChanged'
        QtMocHelpers::SlotData<void(const int)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'onMsaProgressCurrentChanged'
        QtMocHelpers::SlotData<void(const int)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Submission, qt_meta_tag_ZN8Composer10SubmissionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Composer::Submission::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Composer10SubmissionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Composer10SubmissionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Composer10SubmissionE_t>.metaTypes,
    nullptr
} };

void Composer::Submission::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Submission *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progressMin((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->progressMax((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->progress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->updateStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->failed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->succeeded(); break;
        case 6: _t->passwordRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->gotPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->canceled(); break;
        case 9: _t->logged((*reinterpret_cast<std::add_pointer_t<Common::LogKind>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 10: _t->setPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->cancelPassword(); break;
        case 12: _t->gotError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->sent(); break;
        case 14: _t->slotAppendUidKnown((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 15: _t->slotGenUrlAuthReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->slotAppendSucceeded(); break;
        case 17: _t->slotAppendFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->onUpdatingFlagsOfReplyingToSucceded(); break;
        case 19: _t->onUpdatingFlagsOfReplyingToFailed(); break;
        case 20: _t->onUpdatingFlagsOfForwardingSucceeded(); break;
        case 21: _t->onUpdatingFlagsOfForwardingFailed(); break;
        case 22: _t->slotMessageDataAvailable(); break;
        case 23: _t->slotAskForUrl(); break;
        case 24: _t->slotInvokeMsaNow(); break;
        case 25: _t->onMsaProgressMaxChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->onMsaProgressCurrentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Submission::*)(const int )>(_a, &Submission::progressMin, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Submission::*)(const int )>(_a, &Submission::progressMax, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Submission::*)(const int )>(_a, &Submission::progress, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Submission::*)(const QString & )>(_a, &Submission::updateStatusMessage, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Submission::*)(const QString & )>(_a, &Submission::failed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Submission::*)()>(_a, &Submission::succeeded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Submission::*)(const QString & , const QString & )>(_a, &Submission::passwordRequested, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Submission::*)(const QString & )>(_a, &Submission::gotPassword, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Submission::*)()>(_a, &Submission::canceled, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Submission::*)(const Common::LogKind , const QString & , const QString & )>(_a, &Submission::logged, 9))
            return;
    }
}

const QMetaObject *Composer::Submission::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Composer::Submission::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Composer10SubmissionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Composer::Submission::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void Composer::Submission::progressMin(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Composer::Submission::progressMax(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Composer::Submission::progress(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Composer::Submission::updateStatusMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Composer::Submission::failed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Composer::Submission::succeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Composer::Submission::passwordRequested(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Composer::Submission::gotPassword(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Composer::Submission::canceled()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Composer::Submission::logged(const Common::LogKind _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
