/********************************************************************************
** Form generated from reading UI file 'EditIdentity.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITIDENTITY_H
#define UI_EDITIDENTITY_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QWidget>
#include "LineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_EditIdentity
{
public:
    QFormLayout *formLayout;
    QLabel *realNameLabel;
    LineEdit *realNameLineEdit;
    QLabel *emailLabel;
    LineEdit *emailLineEdit;
    LineEdit *organisationLineEdit;
    QLabel *organisationLabel;
    QLabel *signatureLabel;
    QPlainTextEdit *signaturePlainTextEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *EditIdentity)
    {
        if (EditIdentity->objectName().isEmpty())
            EditIdentity->setObjectName("EditIdentity");
        EditIdentity->resize(700, 309);
        EditIdentity->setMinimumSize(QSize(700, 0));
        formLayout = new QFormLayout(EditIdentity);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        realNameLabel = new QLabel(EditIdentity);
        realNameLabel->setObjectName("realNameLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, realNameLabel);

        realNameLineEdit = new LineEdit(EditIdentity);
        realNameLineEdit->setObjectName("realNameLineEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, realNameLineEdit);

        emailLabel = new QLabel(EditIdentity);
        emailLabel->setObjectName("emailLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, emailLabel);

        emailLineEdit = new LineEdit(EditIdentity);
        emailLineEdit->setObjectName("emailLineEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, emailLineEdit);

        organisationLineEdit = new LineEdit(EditIdentity);
        organisationLineEdit->setObjectName("organisationLineEdit");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, organisationLineEdit);

        organisationLabel = new QLabel(EditIdentity);
        organisationLabel->setObjectName("organisationLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, organisationLabel);

        signatureLabel = new QLabel(EditIdentity);
        signatureLabel->setObjectName("signatureLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, signatureLabel);

        signaturePlainTextEdit = new QPlainTextEdit(EditIdentity);
        signaturePlainTextEdit->setObjectName("signaturePlainTextEdit");
        signaturePlainTextEdit->setLineWrapMode(QPlainTextEdit::NoWrap);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, signaturePlainTextEdit);

        buttonBox = new QDialogButtonBox(EditIdentity);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, buttonBox);


        retranslateUi(EditIdentity);

        QMetaObject::connectSlotsByName(EditIdentity);
    } // setupUi

    void retranslateUi(QWidget *EditIdentity)
    {
        EditIdentity->setWindowTitle(QCoreApplication::translate("EditIdentity", "Manage Identity", nullptr));
        realNameLabel->setText(QCoreApplication::translate("EditIdentity", "Real Name", nullptr));
        emailLabel->setText(QCoreApplication::translate("EditIdentity", "E-mail", nullptr));
        organisationLabel->setText(QCoreApplication::translate("EditIdentity", "Organisation", nullptr));
        signatureLabel->setText(QCoreApplication::translate("EditIdentity", "Signature", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditIdentity: public Ui_EditIdentity {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITIDENTITY_H
