/****************************************************************************
** Meta object code from reading C++ file 'AddressbookPlugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Plugins/AddressbookPlugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AddressbookPlugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Plugins14AddressbookJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Plugins::AddressbookJob::qt_create_metaobjectdata<qt_meta_tag_ZN7Plugins14AddressbookJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plugins::AddressbookJob",
        "error",
        "",
        "Plugins::AddressbookJob::Error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(Plugins::AddressbookJob::Error)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 1 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AddressbookJob, qt_meta_tag_ZN7Plugins14AddressbookJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plugins::AddressbookJob::staticMetaObject = { {
    QMetaObject::SuperData::link<PluginJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins14AddressbookJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins14AddressbookJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Plugins14AddressbookJobE_t>.metaTypes,
    nullptr
} };

void Plugins::AddressbookJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AddressbookJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<Plugins::AddressbookJob::Error>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AddressbookJob::*)(Plugins::AddressbookJob::Error )>(_a, &AddressbookJob::error, 0))
            return;
    }
}

const QMetaObject *Plugins::AddressbookJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plugins::AddressbookJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins14AddressbookJobE_t>.strings))
        return static_cast<void*>(this);
    return PluginJob::qt_metacast(_clname);
}

int Plugins::AddressbookJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PluginJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Plugins::AddressbookJob::error(Plugins::AddressbookJob::Error _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN7Plugins24AddressbookCompletionJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Plugins::AddressbookCompletionJob::qt_create_metaobjectdata<qt_meta_tag_ZN7Plugins24AddressbookCompletionJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plugins::AddressbookCompletionJob",
        "completionAvailable",
        "",
        "Plugins::NameEmailList",
        "completion"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'completionAvailable'
        QtMocHelpers::SignalData<void(const Plugins::NameEmailList &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AddressbookCompletionJob, qt_meta_tag_ZN7Plugins24AddressbookCompletionJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plugins::AddressbookCompletionJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AddressbookJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins24AddressbookCompletionJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins24AddressbookCompletionJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Plugins24AddressbookCompletionJobE_t>.metaTypes,
    nullptr
} };

void Plugins::AddressbookCompletionJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AddressbookCompletionJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->completionAvailable((*reinterpret_cast<std::add_pointer_t<Plugins::NameEmailList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AddressbookCompletionJob::*)(const Plugins::NameEmailList & )>(_a, &AddressbookCompletionJob::completionAvailable, 0))
            return;
    }
}

const QMetaObject *Plugins::AddressbookCompletionJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plugins::AddressbookCompletionJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins24AddressbookCompletionJobE_t>.strings))
        return static_cast<void*>(this);
    return AddressbookJob::qt_metacast(_clname);
}

int Plugins::AddressbookCompletionJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AddressbookJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Plugins::AddressbookCompletionJob::completionAvailable(const Plugins::NameEmailList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN7Plugins19AddressbookNamesJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Plugins::AddressbookNamesJob::qt_create_metaobjectdata<qt_meta_tag_ZN7Plugins19AddressbookNamesJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plugins::AddressbookNamesJob",
        "prettyNamesForAddressAvailable",
        "",
        "displayNames"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'prettyNamesForAddressAvailable'
        QtMocHelpers::SignalData<void(const QStringList &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AddressbookNamesJob, qt_meta_tag_ZN7Plugins19AddressbookNamesJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plugins::AddressbookNamesJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AddressbookJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins19AddressbookNamesJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins19AddressbookNamesJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Plugins19AddressbookNamesJobE_t>.metaTypes,
    nullptr
} };

void Plugins::AddressbookNamesJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AddressbookNamesJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->prettyNamesForAddressAvailable((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AddressbookNamesJob::*)(const QStringList & )>(_a, &AddressbookNamesJob::prettyNamesForAddressAvailable, 0))
            return;
    }
}

const QMetaObject *Plugins::AddressbookNamesJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plugins::AddressbookNamesJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins19AddressbookNamesJobE_t>.strings))
        return static_cast<void*>(this);
    return AddressbookJob::qt_metacast(_clname);
}

int Plugins::AddressbookNamesJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AddressbookJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Plugins::AddressbookNamesJob::prettyNamesForAddressAvailable(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN7Plugins17AddressbookPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto Plugins::AddressbookPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN7Plugins17AddressbookPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plugins::AddressbookPlugin",
        "requestCompletion",
        "Plugins::AddressbookCompletionJob*",
        "",
        "input",
        "ignores",
        "max",
        "requestPrettyNamesForAddress",
        "Plugins::AddressbookNamesJob*",
        "email",
        "openAddressbookWindow",
        "openContactWindow",
        "displayName"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'requestCompletion'
        QtMocHelpers::SlotData<Plugins::AddressbookCompletionJob *(const QString &, const QStringList &, int)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QStringList, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'requestCompletion'
        QtMocHelpers::SlotData<Plugins::AddressbookCompletionJob *(const QString &, const QStringList &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QStringList, 5 },
        }}),
        // Slot 'requestCompletion'
        QtMocHelpers::SlotData<Plugins::AddressbookCompletionJob *(const QString &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'requestPrettyNamesForAddress'
        QtMocHelpers::SlotData<Plugins::AddressbookNamesJob *(const QString &)>(7, 3, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'openAddressbookWindow'
        QtMocHelpers::SlotData<void()>(10, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openContactWindow'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(11, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AddressbookPlugin, qt_meta_tag_ZN7Plugins17AddressbookPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plugins::AddressbookPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins17AddressbookPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins17AddressbookPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Plugins17AddressbookPluginE_t>.metaTypes,
    nullptr
} };

void Plugins::AddressbookPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AddressbookPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Plugins::AddressbookCompletionJob* _r = _t->requestCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Plugins::AddressbookCompletionJob**>(_a[0]) = std::move(_r); }  break;
        case 1: { Plugins::AddressbookCompletionJob* _r = _t->requestCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Plugins::AddressbookCompletionJob**>(_a[0]) = std::move(_r); }  break;
        case 2: { Plugins::AddressbookCompletionJob* _r = _t->requestCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Plugins::AddressbookCompletionJob**>(_a[0]) = std::move(_r); }  break;
        case 3: { Plugins::AddressbookNamesJob* _r = _t->requestPrettyNamesForAddress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Plugins::AddressbookNamesJob**>(_a[0]) = std::move(_r); }  break;
        case 4: _t->openAddressbookWindow(); break;
        case 5: _t->openContactWindow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *Plugins::AddressbookPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plugins::AddressbookPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Plugins17AddressbookPluginE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plugins::AddressbookPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
