/****************************************************************************
** Meta object code from reading C++ file 'Window.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Gui/Window.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Window.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Gui10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::MainWindow",
        "slotComposeMailUrl",
        "",
        "QUrl",
        "url",
        "slotComposeMail",
        "invokeContactEditor",
        "showContextMenuMboxTree",
        "QPoint",
        "position",
        "showContextMenuMsgListTree",
        "slotReloadMboxList",
        "slotResyncMbox",
        "alertReceived",
        "message",
        "networkPolicyOffline",
        "networkPolicyExpensive",
        "networkPolicyOnline",
        "slotShowSettings",
        "slotShowImapInfo",
        "slotExpunge",
        "imapError",
        "networkError",
        "cacheError",
        "authenticationRequested",
        "authenticationContinue",
        "pass",
        "errorMessage",
        "checkSslPolicy",
        "slotManageContact",
        "slotEditDraft",
        "slotReplyTo",
        "slotReplyAllButMe",
        "slotReplyAll",
        "slotReplyList",
        "slotReplyGuess",
        "slotForwardAsAttachment",
        "slotResend",
        "slotUpdateMessageActions",
        "handleTag",
        "checked",
        "index",
        "handleMarkAsRead",
        "handleMarkAsDeleted",
        "handleMarkAsFlagged",
        "handleMarkAsJunk",
        "handleMarkAsNotJunk",
        "slotMoveToArchiveFailed",
        "error",
        "handleMoveToArchive",
        "slotNextUnread",
        "slotPreviousUnread",
        "msgListClicked",
        "QModelIndex",
        "openCompleteMessageWidget",
        "slotCreateMailboxBelowCurrent",
        "slotMarkCurrentMailboxRead",
        "slotCreateTopMailbox",
        "slotDeleteCurrentMailbox",
        "handleTrayIconChange",
        "slotSubscribeCurrentMailbox",
        "slotShowOnlySubscribed",
        "updateMessageFlags",
        "updateMessageFlagsOf",
        "scrollMessageUp",
        "slotMessageModelChanged",
        "QAbstractItemModel*",
        "model",
        "showConnectionStatus",
        "parserId",
        "Imap::ConnectionState",
        "state",
        "slotShowLinkTarget",
        "link",
        "slotShowAboutTrojita",
        "slotSaveCurrentMessageBody",
        "slotViewMsgSource",
        "slotViewMsgHeaders",
        "slotThreadMsgList",
        "slotHideRead",
        "slotSortingPreferenceChanged",
        "slotSortingConfirmed",
        "column",
        "Qt::SortOrder",
        "order",
        "slotSearchRequested",
        "searchConditions",
        "slotCapabilitiesUpdated",
        "capabilities",
        "slotMailboxDeleteFailed",
        "mailbox",
        "msg",
        "slotMailboxCreateFailed",
        "slotMailboxSyncFailed",
        "slotMailboxChanged",
        "slotDownloadTransferError",
        "errorString",
        "slotDownloadMessageFileNameRequested",
        "QString*",
        "fileName",
        "slotScrollToUnseenMessage",
        "slotScrollToCurrent",
        "slotUpdateWindowTitle",
        "slotLayoutCompact",
        "slotLayoutWide",
        "slotLayoutOneAtTime",
        "saveSizesAndState",
        "saveRawStateSetting",
        "enabled",
        "possiblyLoadMessageOnSplittersChanged",
        "updateNetworkIndication",
        "desktopGeometryChanged",
        "slotIconActivated",
        "QSystemTrayIcon::ActivationReason",
        "reason",
        "slotToggleSysTray",
        "slotResetReconnectState",
        "slotPluginsChanged",
        "showStatusMessage",
        "slotFavoriteTagsChanged",
        "recoverDrafts"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotComposeMailUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotComposeMail'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'invokeContactEditor'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showContextMenuMboxTree'
        QtMocHelpers::SlotData<void(const QPoint &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'showContextMenuMsgListTree'
        QtMocHelpers::SlotData<void(const QPoint &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotReloadMboxList'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResyncMbox'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'alertReceived'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'networkPolicyOffline'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'networkPolicyExpensive'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'networkPolicyOnline'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowSettings'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowImapInfo'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExpunge'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'imapError'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'networkError'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'cacheError'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'authenticationRequested'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'authenticationContinue'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'authenticationContinue'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'checkSslPolicy'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotManageContact'
        QtMocHelpers::SlotData<void(const QUrl &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotEditDraft'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReplyTo'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReplyAllButMe'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReplyAll'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReplyList'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReplyGuess'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotForwardAsAttachment'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResend'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateMessageActions'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleTag'
        QtMocHelpers::SlotData<void(const bool, const int)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 40 }, { QMetaType::Int, 41 },
        }}),
        // Slot 'handleMarkAsRead'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'handleMarkAsDeleted'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'handleMarkAsFlagged'
        QtMocHelpers::SlotData<void(const bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'handleMarkAsJunk'
        QtMocHelpers::SlotData<void(const bool)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'handleMarkAsNotJunk'
        QtMocHelpers::SlotData<void(const bool)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotMoveToArchiveFailed'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'handleMoveToArchive'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNextUnread'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPreviousUnread'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'msgListClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 53, 2 },
        }}),
        // Slot 'openCompleteMessageWidget'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateMailboxBelowCurrent'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMarkCurrentMailboxRead'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateTopMailbox'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteCurrentMailbox'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleTrayIconChange'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSubscribeCurrentMailbox'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowOnlySubscribed'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMessageFlags'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMessageFlagsOf'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 53, 41 },
        }}),
        // Slot 'scrollMessageUp'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMessageModelChanged'
        QtMocHelpers::SlotData<void(QAbstractItemModel *)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 66, 67 },
        }}),
        // Slot 'showConnectionStatus'
        QtMocHelpers::SlotData<void(uint, Imap::ConnectionState)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 69 }, { 0x80000000 | 70, 71 },
        }}),
        // Slot 'slotShowLinkTarget'
        QtMocHelpers::SlotData<void(const QString &)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 73 },
        }}),
        // Slot 'slotShowAboutTrojita'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveCurrentMessageBody'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotViewMsgSource'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotViewMsgHeaders'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotThreadMsgList'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotHideRead'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSortingPreferenceChanged'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSortingConfirmed'
        QtMocHelpers::SlotData<void(int, Qt::SortOrder)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 82 }, { 0x80000000 | 83, 84 },
        }}),
        // Slot 'slotSearchRequested'
        QtMocHelpers::SlotData<void(const QStringList &)>(85, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 86 },
        }}),
        // Slot 'slotCapabilitiesUpdated'
        QtMocHelpers::SlotData<void(const QStringList &)>(87, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 88 },
        }}),
        // Slot 'slotMailboxDeleteFailed'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(89, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 90 }, { QMetaType::QString, 91 },
        }}),
        // Slot 'slotMailboxCreateFailed'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(92, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 90 }, { QMetaType::QString, 91 },
        }}),
        // Slot 'slotMailboxSyncFailed'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 90 }, { QMetaType::QString, 91 },
        }}),
        // Slot 'slotMailboxChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(94, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 53, 90 },
        }}),
        // Slot 'slotDownloadTransferError'
        QtMocHelpers::SlotData<void(const QString &)>(95, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 96 },
        }}),
        // Slot 'slotDownloadMessageFileNameRequested'
        QtMocHelpers::SlotData<void(QString *)>(97, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 98, 99 },
        }}),
        // Slot 'slotScrollToUnseenMessage'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotScrollToCurrent'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateWindowTitle'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLayoutCompact'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLayoutWide'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLayoutOneAtTime'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveSizesAndState'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveRawStateSetting'
        QtMocHelpers::SlotData<void(bool)>(107, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 108 },
        }}),
        // Slot 'possiblyLoadMessageOnSplittersChanged'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateNetworkIndication'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'desktopGeometryChanged'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotIconActivated'
        QtMocHelpers::SlotData<void(const QSystemTrayIcon::ActivationReason)>(112, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 113, 114 },
        }}),
        // Slot 'slotToggleSysTray'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResetReconnectState'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPluginsChanged'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showStatusMessage'
        QtMocHelpers::SlotData<void(const QString &)>(118, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'slotFavoriteTagsChanged'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'recoverDrafts'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN3Gui10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui10MainWindowE_t>.metaTypes,
    nullptr
} };

void Gui::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotComposeMailUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 1: _t->slotComposeMail(); break;
        case 2: _t->invokeContactEditor(); break;
        case 3: _t->showContextMenuMboxTree((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 4: _t->showContextMenuMsgListTree((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 5: _t->slotReloadMboxList(); break;
        case 6: _t->slotResyncMbox(); break;
        case 7: _t->alertReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->networkPolicyOffline(); break;
        case 9: _t->networkPolicyExpensive(); break;
        case 10: _t->networkPolicyOnline(); break;
        case 11: _t->slotShowSettings(); break;
        case 12: _t->slotShowImapInfo(); break;
        case 13: _t->slotExpunge(); break;
        case 14: _t->imapError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->networkError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->cacheError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->authenticationRequested(); break;
        case 18: _t->authenticationContinue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->authenticationContinue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->checkSslPolicy(); break;
        case 21: _t->slotManageContact((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 22: _t->slotEditDraft(); break;
        case 23: _t->slotReplyTo(); break;
        case 24: _t->slotReplyAllButMe(); break;
        case 25: _t->slotReplyAll(); break;
        case 26: _t->slotReplyList(); break;
        case 27: _t->slotReplyGuess(); break;
        case 28: _t->slotForwardAsAttachment(); break;
        case 29: _t->slotResend(); break;
        case 30: _t->slotUpdateMessageActions(); break;
        case 31: _t->handleTag((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 32: _t->handleMarkAsRead((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->handleMarkAsDeleted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->handleMarkAsFlagged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->handleMarkAsJunk((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->handleMarkAsNotJunk((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->slotMoveToArchiveFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->handleMoveToArchive(); break;
        case 39: _t->slotNextUnread(); break;
        case 40: _t->slotPreviousUnread(); break;
        case 41: _t->msgListClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 42: _t->openCompleteMessageWidget(); break;
        case 43: _t->slotCreateMailboxBelowCurrent(); break;
        case 44: _t->slotMarkCurrentMailboxRead(); break;
        case 45: _t->slotCreateTopMailbox(); break;
        case 46: _t->slotDeleteCurrentMailbox(); break;
        case 47: _t->handleTrayIconChange(); break;
        case 48: _t->slotSubscribeCurrentMailbox(); break;
        case 49: _t->slotShowOnlySubscribed(); break;
        case 50: _t->updateMessageFlags(); break;
        case 51: _t->updateMessageFlagsOf((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 52: _t->scrollMessageUp(); break;
        case 53: _t->slotMessageModelChanged((*reinterpret_cast<std::add_pointer_t<QAbstractItemModel*>>(_a[1]))); break;
        case 54: _t->showConnectionStatus((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::ConnectionState>>(_a[2]))); break;
        case 55: _t->slotShowLinkTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 56: _t->slotShowAboutTrojita(); break;
        case 57: _t->slotSaveCurrentMessageBody(); break;
        case 58: _t->slotViewMsgSource(); break;
        case 59: _t->slotViewMsgHeaders(); break;
        case 60: _t->slotThreadMsgList(); break;
        case 61: _t->slotHideRead(); break;
        case 62: _t->slotSortingPreferenceChanged(); break;
        case 63: _t->slotSortingConfirmed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[2]))); break;
        case 64: _t->slotSearchRequested((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 65: _t->slotCapabilitiesUpdated((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 66: _t->slotMailboxDeleteFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 67: _t->slotMailboxCreateFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 68: _t->slotMailboxSyncFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 69: _t->slotMailboxChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 70: _t->slotDownloadTransferError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 71: _t->slotDownloadMessageFileNameRequested((*reinterpret_cast<std::add_pointer_t<QString*>>(_a[1]))); break;
        case 72: _t->slotScrollToUnseenMessage(); break;
        case 73: _t->slotScrollToCurrent(); break;
        case 74: _t->slotUpdateWindowTitle(); break;
        case 75: _t->slotLayoutCompact(); break;
        case 76: _t->slotLayoutWide(); break;
        case 77: _t->slotLayoutOneAtTime(); break;
        case 78: _t->saveSizesAndState(); break;
        case 79: _t->saveRawStateSetting((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 80: _t->possiblyLoadMessageOnSplittersChanged(); break;
        case 81: _t->updateNetworkIndication(); break;
        case 82: _t->desktopGeometryChanged(); break;
        case 83: _t->slotIconActivated((*reinterpret_cast<std::add_pointer_t<QSystemTrayIcon::ActivationReason>>(_a[1]))); break;
        case 84: _t->slotToggleSysTray(); break;
        case 85: _t->slotResetReconnectState(); break;
        case 86: _t->slotPluginsChanged(); break;
        case 87: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 88: _t->slotFavoriteTagsChanged(); break;
        case 89: _t->recoverDrafts(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 53:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractItemModel* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Gui::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int Gui::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 90)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 90;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 90)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 90;
    }
    return _id;
}
QT_WARNING_POP
