/****************************************************************************
** Meta object code from reading C++ file 'ThreadingMsgListModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Imap/Model/ThreadingMsgListModel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ThreadingMsgListModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Imap7Mailbox21ThreadingMsgListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Imap::Mailbox::ThreadingMsgListModel::qt_create_metaobjectdata<qt_meta_tag_ZN4Imap7Mailbox21ThreadingMsgListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Imap::Mailbox::ThreadingMsgListModel",
        "sortingFailed",
        "",
        "resetMe",
        "handleDataChanged",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "handleRowsAboutToBeRemoved",
        "parent",
        "start",
        "end",
        "handleRowsRemoved",
        "handleRowsAboutToBeInserted",
        "handleRowsInserted",
        "slotThreadingAvailable",
        "mailbox",
        "algorithm",
        "searchCriteria",
        "QList<Imap::Responses::ThreadingNode>",
        "mapping",
        "slotThreadingFailed",
        "applyThreading",
        "slotSortingAvailable",
        "Imap::Uids",
        "uids",
        "slotSortingFailed",
        "slotSortingIncrementalUpdate",
        "Imap::Responses::ESearch::IncrementalContextData_t",
        "updates",
        "applySort",
        "setUserWantsThreading",
        "enable",
        "setUserSearchingSortingPreference",
        "searchConditions",
        "Imap::Mailbox::ThreadingMsgListModel::SortCriterium",
        "criterium",
        "Qt::SortOrder",
        "order",
        "slotIncrementalThreadingAvailable",
        "Imap::Responses::ESearch::IncrementalThreadingData_t",
        "data",
        "slotIncrementalThreadingFailed",
        "delayedPrune",
        "currentSortOrder",
        "SortCriterium",
        "SORT_NONE",
        "SORT_ARRIVAL",
        "SORT_CC",
        "SORT_DATE",
        "SORT_FROM",
        "SORT_SIZE",
        "SORT_SUBJECT",
        "SORT_TO"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sortingFailed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetMe'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Slot 'handleRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'handleRowsRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'handleRowsAboutToBeInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'handleRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'slotThreadingAvailable'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QByteArray &, const QStringList &, const QVector<Imap::Responses::ThreadingNode> &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 16 }, { QMetaType::QByteArray, 17 }, { QMetaType::QStringList, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'slotThreadingFailed'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QByteArray &, const QStringList &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 16 }, { QMetaType::QByteArray, 17 }, { QMetaType::QStringList, 18 },
        }}),
        // Slot 'applyThreading'
        QtMocHelpers::SlotData<void(const QVector<Imap::Responses::ThreadingNode> &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'slotSortingAvailable'
        QtMocHelpers::SlotData<void(const Imap::Uids &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'slotSortingFailed'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSortingIncrementalUpdate'
        QtMocHelpers::SlotData<void(const Imap::Responses::ESearch::IncrementalContextData_t &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'applySort'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setUserWantsThreading'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'setUserSearchingSortingPreference'
        QtMocHelpers::SlotData<bool(const QStringList &, const Imap::Mailbox::ThreadingMsgListModel::SortCriterium, const Qt::SortOrder)>(33, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 34 }, { 0x80000000 | 35, 36 }, { 0x80000000 | 37, 38 },
        }}),
        // Slot 'setUserSearchingSortingPreference'
        QtMocHelpers::SlotData<bool(const QStringList &, const Imap::Mailbox::ThreadingMsgListModel::SortCriterium)>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QStringList, 34 }, { 0x80000000 | 35, 36 },
        }}),
        // Slot 'slotIncrementalThreadingAvailable'
        QtMocHelpers::SlotData<void(const Imap::Responses::ESearch::IncrementalThreadingData_t &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Slot 'slotIncrementalThreadingFailed'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'delayedPrune'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'currentSortOrder'
        QtMocHelpers::MethodData<Qt::SortOrder() const>(44, 2, QMC::AccessPublic, 0x80000000 | 37),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SortCriterium'
        QtMocHelpers::EnumData<enum SortCriterium>(45, 45, QMC::EnumIsScoped).add({
            {   46, SortCriterium::SORT_NONE },
            {   47, SortCriterium::SORT_ARRIVAL },
            {   48, SortCriterium::SORT_CC },
            {   49, SortCriterium::SORT_DATE },
            {   50, SortCriterium::SORT_FROM },
            {   51, SortCriterium::SORT_SIZE },
            {   52, SortCriterium::SORT_SUBJECT },
            {   53, SortCriterium::SORT_TO },
        }),
    };
    return QtMocHelpers::metaObjectData<ThreadingMsgListModel, qt_meta_tag_ZN4Imap7Mailbox21ThreadingMsgListModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Imap::Mailbox::ThreadingMsgListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox21ThreadingMsgListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox21ThreadingMsgListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Imap7Mailbox21ThreadingMsgListModelE_t>.metaTypes,
    nullptr
} };

void Imap::Mailbox::ThreadingMsgListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ThreadingMsgListModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sortingFailed(); break;
        case 1: _t->resetMe(); break;
        case 2: _t->handleDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 3: _t->handleRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->handleRowsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 5: _t->handleRowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->handleRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->slotThreadingAvailable((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QList<Imap::Responses::ThreadingNode>>>(_a[4]))); break;
        case 8: _t->slotThreadingFailed((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 9: _t->applyThreading((*reinterpret_cast<std::add_pointer_t<QList<Imap::Responses::ThreadingNode>>>(_a[1]))); break;
        case 10: _t->slotSortingAvailable((*reinterpret_cast<std::add_pointer_t<Imap::Uids>>(_a[1]))); break;
        case 11: _t->slotSortingFailed(); break;
        case 12: _t->slotSortingIncrementalUpdate((*reinterpret_cast<std::add_pointer_t<Imap::Responses::ESearch::IncrementalContextData_t>>(_a[1]))); break;
        case 13: _t->applySort(); break;
        case 14: _t->setUserWantsThreading((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: { bool _r = _t->setUserSearchingSortingPreference((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::Mailbox::ThreadingMsgListModel::SortCriterium>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->setUserSearchingSortingPreference((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::Mailbox::ThreadingMsgListModel::SortCriterium>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->slotIncrementalThreadingAvailable((*reinterpret_cast<std::add_pointer_t<Imap::Responses::ESearch::IncrementalThreadingData_t>>(_a[1]))); break;
        case 18: _t->slotIncrementalThreadingFailed(); break;
        case 19: _t->delayedPrune(); break;
        case 20: { Qt::SortOrder _r = _t->currentSortOrder();
            if (_a[0]) *reinterpret_cast<Qt::SortOrder*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Imap::Responses::ThreadingNode> >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Imap::Responses::ThreadingNode> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ThreadingMsgListModel::*)()>(_a, &ThreadingMsgListModel::sortingFailed, 0))
            return;
    }
}

const QMetaObject *Imap::Mailbox::ThreadingMsgListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Imap::Mailbox::ThreadingMsgListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox21ThreadingMsgListModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractProxyModel::qt_metacast(_clname);
}

int Imap::Mailbox::ThreadingMsgListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void Imap::Mailbox::ThreadingMsgListModel::sortingFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
