/****************************************************************************
** Meta object code from reading C++ file 'GpgMe++.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Cryptography/GpgMe++.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GpgMe++.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Cryptography9GpgMePartE_t {};
} // unnamed namespace

template <> constexpr inline auto Cryptography::GpgMePart::qt_create_metaobjectdata<qt_meta_tag_ZN12Cryptography9GpgMePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cryptography::GpgMePart",
        "forwardFailure",
        "",
        "statusTLDR",
        "statusLong",
        "statusIcon",
        "handleDataChanged",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "internalUpdateState",
        "Cryptography::SignatureDataBundle",
        "d"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'forwardFailure'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'handleDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(6, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 },
        }}),
        // Slot 'internalUpdateState'
        QtMocHelpers::SlotData<void(const Cryptography::SignatureDataBundle &)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GpgMePart, qt_meta_tag_ZN12Cryptography9GpgMePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cryptography::GpgMePart::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Cryptography9GpgMePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Cryptography9GpgMePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Cryptography9GpgMePartE_t>.metaTypes,
    nullptr
} };

void Cryptography::GpgMePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GpgMePart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->forwardFailure((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->handleDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 2: _t->internalUpdateState((*reinterpret_cast<std::add_pointer_t<Cryptography::SignatureDataBundle>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Cryptography::SignatureDataBundle >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Cryptography::GpgMePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cryptography::GpgMePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Cryptography9GpgMePartE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "LocalMessagePart"))
        return static_cast< LocalMessagePart*>(this);
    return QObject::qt_metacast(_clname);
}

int Cryptography::GpgMePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN12Cryptography11GpgMeSignedE_t {};
} // unnamed namespace

template <> constexpr inline auto Cryptography::GpgMeSigned::qt_create_metaobjectdata<qt_meta_tag_ZN12Cryptography11GpgMeSignedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cryptography::GpgMeSigned",
        "handleDataChanged",
        "",
        "QModelIndex",
        "topLeft",
        "bottomRight"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GpgMeSigned, qt_meta_tag_ZN12Cryptography11GpgMeSignedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cryptography::GpgMeSigned::staticMetaObject = { {
    QMetaObject::SuperData::link<GpgMePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Cryptography11GpgMeSignedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Cryptography11GpgMeSignedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Cryptography11GpgMeSignedE_t>.metaTypes,
    nullptr
} };

void Cryptography::GpgMeSigned::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GpgMeSigned *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *Cryptography::GpgMeSigned::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cryptography::GpgMeSigned::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Cryptography11GpgMeSignedE_t>.strings))
        return static_cast<void*>(this);
    return GpgMePart::qt_metacast(_clname);
}

int Cryptography::GpgMeSigned::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GpgMePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN12Cryptography14GpgMeEncryptedE_t {};
} // unnamed namespace

template <> constexpr inline auto Cryptography::GpgMeEncrypted::qt_create_metaobjectdata<qt_meta_tag_ZN12Cryptography14GpgMeEncryptedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cryptography::GpgMeEncrypted",
        "handleDataChanged",
        "",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "processDecryptedData",
        "ok",
        "data"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Slot 'processDecryptedData'
        QtMocHelpers::SlotData<void(const bool, const QByteArray &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 7 }, { QMetaType::QByteArray, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GpgMeEncrypted, qt_meta_tag_ZN12Cryptography14GpgMeEncryptedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cryptography::GpgMeEncrypted::staticMetaObject = { {
    QMetaObject::SuperData::link<GpgMePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Cryptography14GpgMeEncryptedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Cryptography14GpgMeEncryptedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Cryptography14GpgMeEncryptedE_t>.metaTypes,
    nullptr
} };

void Cryptography::GpgMeEncrypted::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GpgMeEncrypted *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 1: _t->processDecryptedData((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *Cryptography::GpgMeEncrypted::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cryptography::GpgMeEncrypted::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Cryptography14GpgMeEncryptedE_t>.strings))
        return static_cast<void*>(this);
    return GpgMePart::qt_metacast(_clname);
}

int Cryptography::GpgMeEncrypted::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GpgMePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
