/****************************************************************************
** Meta object code from reading C++ file 'AbstractMSA.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/MSA/AbstractMSA.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractMSA.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3MSA11AbstractMSAE_t {};
} // unnamed namespace

template <> constexpr inline auto MSA::AbstractMSA::qt_create_metaobjectdata<qt_meta_tag_ZN3MSA11AbstractMSAE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MSA::AbstractMSA",
        "connecting",
        "",
        "passwordRequested",
        "user",
        "host",
        "sending",
        "sent",
        "error",
        "message",
        "progressMax",
        "max",
        "progress",
        "num",
        "logged",
        "Common::LogKind",
        "kind",
        "source",
        "cancel",
        "setPassword",
        "password"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connecting'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordRequested'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'sending'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sent'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'progressMax'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'progress'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'logged'
        QtMocHelpers::SignalData<void(const Common::LogKind, const QString &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPassword'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractMSA, qt_meta_tag_ZN3MSA11AbstractMSAE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MSA::AbstractMSA::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA11AbstractMSAE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA11AbstractMSAE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3MSA11AbstractMSAE_t>.metaTypes,
    nullptr
} };

void MSA::AbstractMSA::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractMSA *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connecting(); break;
        case 1: _t->passwordRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->sending(); break;
        case 3: _t->sent(); break;
        case 4: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->progressMax((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->progress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->logged((*reinterpret_cast<std::add_pointer_t<Common::LogKind>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 8: _t->cancel(); break;
        case 9: _t->setPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractMSA::*)()>(_a, &AbstractMSA::connecting, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMSA::*)(const QString & , const QString & )>(_a, &AbstractMSA::passwordRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMSA::*)()>(_a, &AbstractMSA::sending, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMSA::*)()>(_a, &AbstractMSA::sent, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMSA::*)(const QString & )>(_a, &AbstractMSA::error, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMSA::*)(int )>(_a, &AbstractMSA::progressMax, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMSA::*)(int )>(_a, &AbstractMSA::progress, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMSA::*)(const Common::LogKind , const QString & , const QString & )>(_a, &AbstractMSA::logged, 7))
            return;
    }
}

const QMetaObject *MSA::AbstractMSA::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MSA::AbstractMSA::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3MSA11AbstractMSAE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MSA::AbstractMSA::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void MSA::AbstractMSA::connecting()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MSA::AbstractMSA::passwordRequested(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void MSA::AbstractMSA::sending()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MSA::AbstractMSA::sent()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MSA::AbstractMSA::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MSA::AbstractMSA::progressMax(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MSA::AbstractMSA::progress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MSA::AbstractMSA::logged(const Common::LogKind _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
