/****************************************************************************
** Meta object code from reading C++ file 'SubtreeModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Imap/Model/SubtreeModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SubtreeModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Imap7Mailbox12SubtreeModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Imap::Mailbox::SubtreeModel::qt_create_metaobjectdata<qt_meta_tag_ZN4Imap7Mailbox12SubtreeModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Imap::Mailbox::SubtreeModel",
        "validityChanged",
        "",
        "handleDataChanged",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "handleModelAboutToBeReset",
        "handleModelReset",
        "handleRowsAboutToBeRemoved",
        "parent",
        "first",
        "last",
        "handleRowsRemoved",
        "handleRowsAboutToBeInserted",
        "handleRowsInserted",
        "setRootItem",
        "rootIndex",
        "setRootItemByOffset",
        "row",
        "setRootOneLevelUp",
        "setOriginalRoot",
        "parentOfRoot",
        "itemsValid"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'validityChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 },
        }}),
        // Slot 'handleModelAboutToBeReset'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleModelReset'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 10 }, { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'handleRowsRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 10 }, { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'handleRowsAboutToBeInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 10 }, { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'handleRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 10 }, { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Method 'setRootItem'
        QtMocHelpers::MethodData<void(QModelIndex)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 17 },
        }}),
        // Method 'setRootItemByOffset'
        QtMocHelpers::MethodData<void(const int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Method 'setRootOneLevelUp'
        QtMocHelpers::MethodData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setOriginalRoot'
        QtMocHelpers::MethodData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'parentOfRoot'
        QtMocHelpers::MethodData<QModelIndex() const>(22, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'itemsValid'
        QtMocHelpers::MethodData<bool() const>(23, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'itemsValid'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SubtreeModel, qt_meta_tag_ZN4Imap7Mailbox12SubtreeModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Imap::Mailbox::SubtreeModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox12SubtreeModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox12SubtreeModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Imap7Mailbox12SubtreeModelE_t>.metaTypes,
    nullptr
} };

void Imap::Mailbox::SubtreeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SubtreeModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->validityChanged(); break;
        case 1: _t->handleDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 2: _t->handleModelAboutToBeReset(); break;
        case 3: _t->handleModelReset(); break;
        case 4: _t->handleRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 5: _t->handleRowsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->handleRowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->handleRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->setRootItem((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->setRootItemByOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setRootOneLevelUp(); break;
        case 11: _t->setOriginalRoot(); break;
        case 12: { QModelIndex _r = _t->parentOfRoot();
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->itemsValid();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SubtreeModel::*)()>(_a, &SubtreeModel::validityChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->itemsValid(); break;
        default: break;
        }
    }
}

const QMetaObject *Imap::Mailbox::SubtreeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Imap::Mailbox::SubtreeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox12SubtreeModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractProxyModel::qt_metacast(_clname);
}

int Imap::Mailbox::SubtreeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Imap::Mailbox::SubtreeModel::validityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN4Imap7Mailbox19SubtreeModelOfModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Imap::Mailbox::SubtreeModelOfModel::qt_create_metaobjectdata<qt_meta_tag_ZN4Imap7Mailbox19SubtreeModelOfModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Imap::Mailbox::SubtreeModelOfModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SubtreeModelOfModel, qt_meta_tag_ZN4Imap7Mailbox19SubtreeModelOfModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Imap::Mailbox::SubtreeModelOfModel::staticMetaObject = { {
    QMetaObject::SuperData::link<SubtreeModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox19SubtreeModelOfModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox19SubtreeModelOfModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Imap7Mailbox19SubtreeModelOfModelE_t>.metaTypes,
    nullptr
} };

void Imap::Mailbox::SubtreeModelOfModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SubtreeModelOfModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Imap::Mailbox::SubtreeModelOfModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Imap::Mailbox::SubtreeModelOfModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox19SubtreeModelOfModelE_t>.strings))
        return static_cast<void*>(this);
    return SubtreeModel::qt_metacast(_clname);
}

int Imap::Mailbox::SubtreeModelOfModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SubtreeModel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Imap7Mailbox26SubtreeModelOfMailboxModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Imap::Mailbox::SubtreeModelOfMailboxModel::qt_create_metaobjectdata<qt_meta_tag_ZN4Imap7Mailbox26SubtreeModelOfMailboxModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Imap::Mailbox::SubtreeModelOfMailboxModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SubtreeModelOfMailboxModel, qt_meta_tag_ZN4Imap7Mailbox26SubtreeModelOfMailboxModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Imap::Mailbox::SubtreeModelOfMailboxModel::staticMetaObject = { {
    QMetaObject::SuperData::link<SubtreeModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox26SubtreeModelOfMailboxModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox26SubtreeModelOfMailboxModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Imap7Mailbox26SubtreeModelOfMailboxModelE_t>.metaTypes,
    nullptr
} };

void Imap::Mailbox::SubtreeModelOfMailboxModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SubtreeModelOfMailboxModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Imap::Mailbox::SubtreeModelOfMailboxModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Imap::Mailbox::SubtreeModelOfMailboxModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox26SubtreeModelOfMailboxModelE_t>.strings))
        return static_cast<void*>(this);
    return SubtreeModel::qt_metacast(_clname);
}

int Imap::Mailbox::SubtreeModelOfMailboxModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SubtreeModel::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
