/****************************************************************************
** Meta object code from reading C++ file 'NetworkWatcher.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Imap/Model/NetworkWatcher.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'NetworkWatcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Imap7Mailbox14NetworkWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto Imap::Mailbox::NetworkWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN4Imap7Mailbox14NetworkWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Imap::Mailbox::NetworkWatcher",
        "effectiveNetworkPolicyChanged",
        "",
        "reconnectAttemptScheduled",
        "timeout",
        "resetReconnectState",
        "desiredNetworkPolicyChanged",
        "Imap::Mailbox::NetworkPolicy",
        "policy",
        "setNetworkOffline",
        "setNetworkExpensive",
        "setNetworkOnline",
        "attemptReconnect",
        "tryReconnect",
        "handleConnectionStateChanged",
        "parserId",
        "Imap::ConnectionState",
        "state"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'effectiveNetworkPolicyChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reconnectAttemptScheduled'
        QtMocHelpers::SignalData<void(const int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'resetReconnectState'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desiredNetworkPolicyChanged'
        QtMocHelpers::SignalData<void(const Imap::Mailbox::NetworkPolicy)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'setNetworkOffline'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setNetworkExpensive'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setNetworkOnline'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'attemptReconnect'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'tryReconnect'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'handleConnectionStateChanged'
        QtMocHelpers::SlotData<void(uint, Imap::ConnectionState)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::UInt, 15 }, { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetworkWatcher, qt_meta_tag_ZN4Imap7Mailbox14NetworkWatcherE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Imap::Mailbox::NetworkWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox14NetworkWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox14NetworkWatcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Imap7Mailbox14NetworkWatcherE_t>.metaTypes,
    nullptr
} };

void Imap::Mailbox::NetworkWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkWatcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->effectiveNetworkPolicyChanged(); break;
        case 1: _t->reconnectAttemptScheduled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->resetReconnectState(); break;
        case 3: _t->desiredNetworkPolicyChanged((*reinterpret_cast<std::add_pointer_t<Imap::Mailbox::NetworkPolicy>>(_a[1]))); break;
        case 4: _t->setNetworkOffline(); break;
        case 5: _t->setNetworkExpensive(); break;
        case 6: _t->setNetworkOnline(); break;
        case 7: _t->attemptReconnect(); break;
        case 8: _t->tryReconnect(); break;
        case 9: _t->handleConnectionStateChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::ConnectionState>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkWatcher::*)()>(_a, &NetworkWatcher::effectiveNetworkPolicyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkWatcher::*)(const int )>(_a, &NetworkWatcher::reconnectAttemptScheduled, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkWatcher::*)()>(_a, &NetworkWatcher::resetReconnectState, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkWatcher::*)(const Imap::Mailbox::NetworkPolicy )>(_a, &NetworkWatcher::desiredNetworkPolicyChanged, 3))
            return;
    }
}

const QMetaObject *Imap::Mailbox::NetworkWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Imap::Mailbox::NetworkWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap7Mailbox14NetworkWatcherE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Imap::Mailbox::NetworkWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Imap::Mailbox::NetworkWatcher::effectiveNetworkPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Imap::Mailbox::NetworkWatcher::reconnectAttemptScheduled(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Imap::Mailbox::NetworkWatcher::resetReconnectState()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Imap::Mailbox::NetworkWatcher::desiredNetworkPolicyChanged(const Imap::Mailbox::NetworkPolicy _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
