/****************************************************************************
** Meta object code from reading C++ file 'Parser.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Imap/Parser/Parser.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Parser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Imap6ParserE_t {};
} // unnamed namespace

template <> constexpr inline auto Imap::Parser::qt_create_metaobjectdata<qt_meta_tag_ZN4Imap6ParserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Imap::Parser",
        "responseReceived",
        "",
        "Imap::Parser*",
        "parser",
        "lineReceived",
        "line",
        "lineSent",
        "parserWarning",
        "message",
        "const QByteArray*",
        "position",
        "commandQueued",
        "connectionStateChanged",
        "Imap::ConnectionState",
        "capability",
        "Imap::CommandHandle",
        "noop",
        "logout",
        "startTls",
        "login",
        "user",
        "pass",
        "select",
        "mailbox",
        "QList<QByteArray>",
        "params",
        "selectQresync",
        "uidValidity",
        "highestModSeq",
        "Imap::Sequence",
        "knownUids",
        "sequenceSnapshot",
        "uidSnapshot",
        "examine",
        "create",
        "deleteMailbox",
        "rename",
        "oldName",
        "newName",
        "subscribe",
        "unSubscribe",
        "list",
        "reference",
        "returnOptions",
        "lSub",
        "status",
        "fields",
        "append",
        "flags",
        "timestamp",
        "appendCatenate",
        "QList<Imap::Mailbox::CatenatePair>",
        "data",
        "check",
        "close",
        "expunge",
        "search",
        "criteria",
        "charset",
        "fetch",
        "seq",
        "items",
        "QMap<QByteArray,quint64>",
        "uint64Modifiers",
        "store",
        "item",
        "value",
        "copy",
        "uidFetch",
        "uidStore",
        "uidCopy",
        "uidMove",
        "uidExpunge",
        "uidSearch",
        "uidSearchUid",
        "sequence",
        "uidESearchUid",
        "xAtom",
        "Imap::Commands::Command",
        "commands",
        "unSelect",
        "idle",
        "idleDone",
        "idleContinuationWontCome",
        "idleMagicallyTerminatedByServer",
        "namespaceCommand",
        "sort",
        "sortCriteria",
        "searchCriteria",
        "uidSort",
        "thread",
        "algo",
        "uidThread",
        "uidESort",
        "uidESearch",
        "uidEThread",
        "cancelUpdate",
        "tag",
        "idCommand",
        "QMap<QByteArray,QByteArray>",
        "args",
        "enable",
        "extensions",
        "compressDeflate",
        "genUrlAuth",
        "url",
        "mechanism",
        "uidSendmail",
        "uid",
        "Imap::Mailbox::UidSubmitOptionsList",
        "submissionOptions",
        "slotSocketStateChanged",
        "connState",
        "unfreezeAfterEncryption",
        "closeConnection",
        "handleReadyRead",
        "handleDisconnected",
        "reason",
        "executeACommand",
        "executeCommands",
        "finishStartTls",
        "handleSocketEncrypted",
        "handleCompressionPossibleActivated"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'responseReceived'
        QtMocHelpers::SignalData<void(Imap::Parser *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'lineReceived'
        QtMocHelpers::SignalData<void(Imap::Parser *, const QByteArray &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QByteArray, 6 },
        }}),
        // Signal 'lineSent'
        QtMocHelpers::SignalData<void(Imap::Parser *, const QByteArray &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QByteArray, 6 },
        }}),
        // Signal 'parserWarning'
        QtMocHelpers::SignalData<void(Imap::Parser *, const QString &, const QByteArray *, uint)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 9 }, { 0x80000000 | 10, 6 }, { QMetaType::UInt, 11 },
        }}),
        // Signal 'commandQueued'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectionStateChanged'
        QtMocHelpers::SignalData<void(Imap::Parser *, Imap::ConnectionState)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 14, 2 },
        }}),
        // Slot 'capability'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(15, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'noop'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(17, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'logout'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(18, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'startTls'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(19, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'login'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'select'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QList<QByteArray> &)>(23, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'select'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'selectQresync'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const uint, const quint64, const Imap::Sequence &, const Imap::Sequence &, const Imap::Sequence &)>(27, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { QMetaType::UInt, 28 }, { QMetaType::ULongLong, 29 }, { 0x80000000 | 30, 31 },
            { 0x80000000 | 30, 32 }, { 0x80000000 | 30, 33 },
        }}),
        // Slot 'selectQresync'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const uint, const quint64, const Imap::Sequence &, const Imap::Sequence &)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { QMetaType::UInt, 28 }, { QMetaType::ULongLong, 29 }, { 0x80000000 | 30, 31 },
            { 0x80000000 | 30, 32 },
        }}),
        // Slot 'selectQresync'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const uint, const quint64, const Imap::Sequence &)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { QMetaType::UInt, 28 }, { QMetaType::ULongLong, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'selectQresync'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const uint, const quint64)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { QMetaType::UInt, 28 }, { QMetaType::ULongLong, 29 },
        }}),
        // Slot 'examine'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QList<QByteArray> &)>(34, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'examine'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &)>(34, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'create'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &)>(35, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'deleteMailbox'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &)>(36, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'rename'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QString &)>(37, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 38 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'subscribe'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &)>(40, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'unSubscribe'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &)>(41, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'list'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QString &, const QStringList &)>(42, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 43 }, { QMetaType::QString, 24 }, { QMetaType::QStringList, 44 },
        }}),
        // Slot 'list'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QString &)>(42, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 43 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'lSub'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QString &)>(45, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 43 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'status'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QStringList &)>(46, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { QMetaType::QStringList, 47 },
        }}),
        // Slot 'append'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QByteArray &, const QStringList &, const QDateTime &)>(48, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { QMetaType::QByteArray, 9 }, { QMetaType::QStringList, 49 }, { QMetaType::QDateTime, 50 },
        }}),
        // Slot 'append'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QByteArray &, const QStringList &)>(48, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { QMetaType::QByteArray, 9 }, { QMetaType::QStringList, 49 },
        }}),
        // Slot 'append'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QByteArray &)>(48, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { QMetaType::QByteArray, 9 },
        }}),
        // Slot 'appendCatenate'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QList<Imap::Mailbox::CatenatePair> &, const QStringList &, const QDateTime &)>(51, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 52, 53 }, { QMetaType::QStringList, 49 }, { QMetaType::QDateTime, 50 },
        }}),
        // Slot 'appendCatenate'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QList<Imap::Mailbox::CatenatePair> &, const QStringList &)>(51, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 52, 53 }, { QMetaType::QStringList, 49 },
        }}),
        // Slot 'appendCatenate'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QString &, const QList<Imap::Mailbox::CatenatePair> &)>(51, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 52, 53 },
        }}),
        // Slot 'check'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(54, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'close'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(55, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'expunge'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(56, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'search'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QStringList &, const QByteArray &)>(57, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QStringList, 58 }, { QMetaType::QByteArray, 59 },
        }}),
        // Slot 'search'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QStringList &)>(57, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QStringList, 58 },
        }}),
        // Slot 'fetch'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Sequence &, const QStringList &, const QMap<QByteArray,quint64> &)>(60, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 30, 61 }, { QMetaType::QStringList, 62 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'fetch'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Sequence &, const QStringList &)>(60, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { 0x80000000 | 30, 61 }, { QMetaType::QStringList, 62 },
        }}),
        // Slot 'store'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Sequence &, const QString &, const QString &)>(65, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 30, 61 }, { QMetaType::QString, 66 }, { QMetaType::QString, 67 },
        }}),
        // Slot 'copy'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Sequence &, const QString &)>(68, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 30, 61 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'uidFetch'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Sequence &, const QList<QByteArray> &)>(69, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 30, 61 }, { 0x80000000 | 25, 62 },
        }}),
        // Slot 'uidStore'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Sequence &, const QString &, const QString &)>(70, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 30, 61 }, { QMetaType::QString, 66 }, { QMetaType::QString, 67 },
        }}),
        // Slot 'uidCopy'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Sequence &, const QString &)>(71, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 30, 61 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'uidMove'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Sequence &, const QString &)>(72, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 30, 61 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'uidExpunge'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Sequence &)>(73, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 30, 61 },
        }}),
        // Slot 'uidSearch'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QStringList &, const QByteArray &)>(74, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QStringList, 58 }, { QMetaType::QByteArray, 59 },
        }}),
        // Slot 'uidSearch'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QStringList &)>(74, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QStringList, 58 },
        }}),
        // Slot 'uidSearchUid'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QByteArray &)>(75, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QByteArray, 76 },
        }}),
        // Slot 'uidESearchUid'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QByteArray &)>(77, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QByteArray, 76 },
        }}),
        // Slot 'xAtom'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::Commands::Command &)>(78, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 79, 80 },
        }}),
        // Slot 'unSelect'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(81, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'idle'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(82, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'idleDone'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'idleContinuationWontCome'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'idleMagicallyTerminatedByServer'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'namespaceCommand'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(86, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'sort'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QStringList &, const QByteArray &, const QStringList &)>(87, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QStringList, 88 }, { QMetaType::QByteArray, 59 }, { QMetaType::QStringList, 89 },
        }}),
        // Slot 'uidSort'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QStringList &, const QByteArray &, const QStringList &)>(90, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QStringList, 88 }, { QMetaType::QByteArray, 59 }, { QMetaType::QStringList, 89 },
        }}),
        // Slot 'thread'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QByteArray &, const QByteArray &, const QStringList &)>(91, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QByteArray, 92 }, { QMetaType::QByteArray, 59 }, { QMetaType::QStringList, 89 },
        }}),
        // Slot 'uidThread'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QByteArray &, const QByteArray &, const QStringList &)>(93, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QByteArray, 92 }, { QMetaType::QByteArray, 59 }, { QMetaType::QStringList, 89 },
        }}),
        // Slot 'uidESort'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QStringList &, const QByteArray &, const QStringList &, const QStringList &)>(94, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QStringList, 88 }, { QMetaType::QByteArray, 59 }, { QMetaType::QStringList, 89 }, { QMetaType::QStringList, 44 },
        }}),
        // Slot 'uidESearch'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QByteArray &, const QStringList &, const QStringList &)>(95, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QByteArray, 59 }, { QMetaType::QStringList, 89 }, { QMetaType::QStringList, 44 },
        }}),
        // Slot 'uidEThread'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QByteArray &, const QByteArray &, const QStringList &, const QStringList &)>(96, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QByteArray, 92 }, { QMetaType::QByteArray, 59 }, { QMetaType::QStringList, 89 }, { QMetaType::QStringList, 44 },
        }}),
        // Slot 'cancelUpdate'
        QtMocHelpers::SlotData<Imap::CommandHandle(const Imap::CommandHandle &)>(97, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 16, 98 },
        }}),
        // Slot 'idCommand'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(99, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'idCommand'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QMap<QByteArray,QByteArray> &)>(99, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 100, 101 },
        }}),
        // Slot 'enable'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QList<QByteArray> &)>(102, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 25, 103 },
        }}),
        // Slot 'compressDeflate'
        QtMocHelpers::SlotData<Imap::CommandHandle()>(104, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'genUrlAuth'
        QtMocHelpers::SlotData<Imap::CommandHandle(const QByteArray &, const QByteArray)>(105, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QByteArray, 106 }, { QMetaType::QByteArray, 107 },
        }}),
        // Slot 'uidSendmail'
        QtMocHelpers::SlotData<Imap::CommandHandle(const uint, const Imap::Mailbox::UidSubmitOptionsList &)>(108, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::UInt, 109 }, { 0x80000000 | 110, 111 },
        }}),
        // Slot 'slotSocketStateChanged'
        QtMocHelpers::SlotData<void(const Imap::ConnectionState, const QString &)>(112, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 113 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'unfreezeAfterEncryption'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeConnection'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleReadyRead'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleDisconnected'
        QtMocHelpers::SlotData<void(const QString &)>(117, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 118 },
        }}),
        // Slot 'executeACommand'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'executeCommands'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'finishStartTls'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleSocketEncrypted'
        QtMocHelpers::SlotData<void()>(122, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleCompressionPossibleActivated'
        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Parser, qt_meta_tag_ZN4Imap6ParserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Imap::Parser::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap6ParserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap6ParserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Imap6ParserE_t>.metaTypes,
    nullptr
} };

void Imap::Parser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Parser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->responseReceived((*reinterpret_cast<std::add_pointer_t<Imap::Parser*>>(_a[1]))); break;
        case 1: _t->lineReceived((*reinterpret_cast<std::add_pointer_t<Imap::Parser*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 2: _t->lineSent((*reinterpret_cast<std::add_pointer_t<Imap::Parser*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 3: _t->parserWarning((*reinterpret_cast<std::add_pointer_t<Imap::Parser*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const QByteArray*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4]))); break;
        case 4: _t->commandQueued(); break;
        case 5: _t->connectionStateChanged((*reinterpret_cast<std::add_pointer_t<Imap::Parser*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::ConnectionState>>(_a[2]))); break;
        case 6: { Imap::CommandHandle _r = _t->capability();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 7: { Imap::CommandHandle _r = _t->noop();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 8: { Imap::CommandHandle _r = _t->logout();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 9: { Imap::CommandHandle _r = _t->startTls();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 10: { Imap::CommandHandle _r = _t->login((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 11: { Imap::CommandHandle _r = _t->select((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 12: { Imap::CommandHandle _r = _t->select((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 13: { Imap::CommandHandle _r = _t->selectQresync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[6])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 14: { Imap::CommandHandle _r = _t->selectQresync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[5])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 15: { Imap::CommandHandle _r = _t->selectQresync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[4])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 16: { Imap::CommandHandle _r = _t->selectQresync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 17: { Imap::CommandHandle _r = _t->examine((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 18: { Imap::CommandHandle _r = _t->examine((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 19: { Imap::CommandHandle _r = _t->create((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 20: { Imap::CommandHandle _r = _t->deleteMailbox((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 21: { Imap::CommandHandle _r = _t->rename((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 22: { Imap::CommandHandle _r = _t->subscribe((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 23: { Imap::CommandHandle _r = _t->unSubscribe((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 24: { Imap::CommandHandle _r = _t->list((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 25: { Imap::CommandHandle _r = _t->list((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 26: { Imap::CommandHandle _r = _t->lSub((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 27: { Imap::CommandHandle _r = _t->status((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 28: { Imap::CommandHandle _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[4])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 29: { Imap::CommandHandle _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 30: { Imap::CommandHandle _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 31: { Imap::CommandHandle _r = _t->appendCatenate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<Imap::Mailbox::CatenatePair>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[4])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 32: { Imap::CommandHandle _r = _t->appendCatenate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<Imap::Mailbox::CatenatePair>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 33: { Imap::CommandHandle _r = _t->appendCatenate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<Imap::Mailbox::CatenatePair>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 34: { Imap::CommandHandle _r = _t->check();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 35: { Imap::CommandHandle _r = _t->close();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 36: { Imap::CommandHandle _r = _t->expunge();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 37: { Imap::CommandHandle _r = _t->search((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 38: { Imap::CommandHandle _r = _t->search((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 39: { Imap::CommandHandle _r = _t->fetch((*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMap<QByteArray,quint64>>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 40: { Imap::CommandHandle _r = _t->fetch((*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 41: { Imap::CommandHandle _r = _t->store((*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 42: { Imap::CommandHandle _r = _t->copy((*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 43: { Imap::CommandHandle _r = _t->uidFetch((*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 44: { Imap::CommandHandle _r = _t->uidStore((*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 45: { Imap::CommandHandle _r = _t->uidCopy((*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 46: { Imap::CommandHandle _r = _t->uidMove((*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 47: { Imap::CommandHandle _r = _t->uidExpunge((*reinterpret_cast<std::add_pointer_t<Imap::Sequence>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 48: { Imap::CommandHandle _r = _t->uidSearch((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 49: { Imap::CommandHandle _r = _t->uidSearch((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 50: { Imap::CommandHandle _r = _t->uidSearchUid((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 51: { Imap::CommandHandle _r = _t->uidESearchUid((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 52: { Imap::CommandHandle _r = _t->xAtom((*reinterpret_cast<std::add_pointer_t<Imap::Commands::Command>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 53: { Imap::CommandHandle _r = _t->unSelect();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 54: { Imap::CommandHandle _r = _t->idle();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 55: _t->idleDone(); break;
        case 56: _t->idleContinuationWontCome(); break;
        case 57: _t->idleMagicallyTerminatedByServer(); break;
        case 58: { Imap::CommandHandle _r = _t->namespaceCommand();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 59: { Imap::CommandHandle _r = _t->sort((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 60: { Imap::CommandHandle _r = _t->uidSort((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 61: { Imap::CommandHandle _r = _t->thread((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 62: { Imap::CommandHandle _r = _t->uidThread((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 63: { Imap::CommandHandle _r = _t->uidESort((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 64: { Imap::CommandHandle _r = _t->uidESearch((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 65: { Imap::CommandHandle _r = _t->uidEThread((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 66: { Imap::CommandHandle _r = _t->cancelUpdate((*reinterpret_cast<std::add_pointer_t<Imap::CommandHandle>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 67: { Imap::CommandHandle _r = _t->idCommand();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 68: { Imap::CommandHandle _r = _t->idCommand((*reinterpret_cast<std::add_pointer_t<QMap<QByteArray,QByteArray>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 69: { Imap::CommandHandle _r = _t->enable((*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 70: { Imap::CommandHandle _r = _t->compressDeflate();
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 71: { Imap::CommandHandle _r = _t->genUrlAuth((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 72: { Imap::CommandHandle _r = _t->uidSendmail((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Imap::Mailbox::UidSubmitOptionsList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Imap::CommandHandle*>(_a[0]) = std::move(_r); }  break;
        case 73: _t->slotSocketStateChanged((*reinterpret_cast<std::add_pointer_t<Imap::ConnectionState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 74: _t->unfreezeAfterEncryption(); break;
        case 75: _t->closeConnection(); break;
        case 76: _t->handleReadyRead(); break;
        case 77: _t->handleDisconnected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 78: _t->executeACommand(); break;
        case 79: _t->executeCommands(); break;
        case 80: _t->finishStartTls(); break;
        case 81: _t->handleSocketEncrypted(); break;
        case 82: _t->handleCompressionPossibleActivated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Parser* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Parser* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Parser* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Parser* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Imap::Parser* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 69:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Parser::*)(Imap::Parser * )>(_a, &Parser::responseReceived, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Parser::*)(Imap::Parser * , const QByteArray & )>(_a, &Parser::lineReceived, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Parser::*)(Imap::Parser * , const QByteArray & )>(_a, &Parser::lineSent, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Parser::*)(Imap::Parser * , const QString & , const QByteArray * , uint )>(_a, &Parser::parserWarning, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Parser::*)()>(_a, &Parser::commandQueued, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Parser::*)(Imap::Parser * , Imap::ConnectionState )>(_a, &Parser::connectionStateChanged, 5))
            return;
    }
}

const QMetaObject *Imap::Parser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Imap::Parser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Imap6ParserE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Imap::Parser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 83)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 83;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 83)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 83;
    }
    return _id;
}

// SIGNAL 0
void Imap::Parser::responseReceived(Imap::Parser * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Imap::Parser::lineReceived(Imap::Parser * _t1, const QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Imap::Parser::lineSent(Imap::Parser * _t1, const QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Imap::Parser::parserWarning(Imap::Parser * _t1, const QString & _t2, const QByteArray * _t3, uint _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 4
void Imap::Parser::commandQueued()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Imap::Parser::connectionStateChanged(Imap::Parser * _t1, Imap::ConnectionState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
