/****************************************************************************
** Meta object code from reading C++ file 'ComposeWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/Gui/ComposeWidget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ComposeWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Gui13ComposeWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Gui::ComposeWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Gui13ComposeWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gui::ComposeWidget",
        "logged",
        "",
        "Common::LogKind",
        "kind",
        "source",
        "message",
        "calculateMaxVisibleRecipients",
        "collapseRecipients",
        "completeRecipient",
        "QAction*",
        "act",
        "completeRecipients",
        "text",
        "send",
        "gotError",
        "error",
        "sent",
        "updateRecipientList",
        "scrollRecipients",
        "gotoNextInputLineFrom",
        "QWidget*",
        "w",
        "handleFocusChange",
        "scrollToFocus",
        "slotFadeFinished",
        "slotCheckAddressOfSender",
        "slotCheckAddress",
        "QLineEdit*",
        "edit",
        "slotAskForFileAttachment",
        "slotAttachFiles",
        "QList<QUrl>",
        "urls",
        "slotUpdateSignature",
        "updateWindowTitle",
        "autoSaveDraft",
        "setMessageUpdated",
        "setUiWidgetsEnabled",
        "enabled",
        "onCompletionAvailable",
        "Plugins::NameEmailList",
        "completion",
        "onCompletionFailed",
        "Plugins::AddressbookJob::Error",
        "passwordRequested",
        "user",
        "host",
        "passwordError",
        "toggleReplyMarking",
        "updateReplyMarkingAction",
        "updateReplyMode",
        "markReplyModeHandpicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'logged'
        QtMocHelpers::SignalData<void(const Common::LogKind, const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'calculateMaxVisibleRecipients'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'collapseRecipients'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'completeRecipient'
        QtMocHelpers::SlotData<void(QAction *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'completeRecipients'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'send'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotError'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'sent'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateRecipientList'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scrollRecipients'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'gotoNextInputLineFrom'
        QtMocHelpers::SlotData<void(QWidget *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'handleFocusChange'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scrollToFocus'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFadeFinished'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCheckAddressOfSender'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCheckAddress'
        QtMocHelpers::SlotData<void(QLineEdit *)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'slotAskForFileAttachment'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAttachFiles'
        QtMocHelpers::SlotData<void(QList<QUrl>)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'slotUpdateSignature'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWindowTitle'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'autoSaveDraft'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setMessageUpdated'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setUiWidgetsEnabled'
        QtMocHelpers::SlotData<void(const bool)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 39 },
        }}),
        // Slot 'onCompletionAvailable'
        QtMocHelpers::SlotData<void(const Plugins::NameEmailList &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'onCompletionFailed'
        QtMocHelpers::SlotData<void(Plugins::AddressbookJob::Error)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 16 },
        }}),
        // Slot 'passwordRequested'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 46 }, { QMetaType::QString, 47 },
        }}),
        // Slot 'passwordError'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleReplyMarking'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateReplyMarkingAction'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateReplyMode'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'markReplyModeHandpicked'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ComposeWidget, qt_meta_tag_ZN3Gui13ComposeWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gui::ComposeWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui13ComposeWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui13ComposeWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Gui13ComposeWidgetE_t>.metaTypes,
    nullptr
} };

void Gui::ComposeWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ComposeWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->logged((*reinterpret_cast<std::add_pointer_t<Common::LogKind>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->calculateMaxVisibleRecipients(); break;
        case 2: _t->collapseRecipients(); break;
        case 3: _t->completeRecipient((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 4: _t->completeRecipients((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->send(); break;
        case 6: _t->gotError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->sent(); break;
        case 8: _t->updateRecipientList(); break;
        case 9: _t->scrollRecipients((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->gotoNextInputLineFrom((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 11: _t->handleFocusChange(); break;
        case 12: _t->scrollToFocus(); break;
        case 13: _t->slotFadeFinished(); break;
        case 14: _t->slotCheckAddressOfSender(); break;
        case 15: _t->slotCheckAddress((*reinterpret_cast<std::add_pointer_t<QLineEdit*>>(_a[1]))); break;
        case 16: _t->slotAskForFileAttachment(); break;
        case 17: _t->slotAttachFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 18: _t->slotUpdateSignature(); break;
        case 19: _t->updateWindowTitle(); break;
        case 20: _t->autoSaveDraft(); break;
        case 21: _t->setMessageUpdated(); break;
        case 22: _t->setUiWidgetsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->onCompletionAvailable((*reinterpret_cast<std::add_pointer_t<Plugins::NameEmailList>>(_a[1]))); break;
        case 24: _t->onCompletionFailed((*reinterpret_cast<std::add_pointer_t<Plugins::AddressbookJob::Error>>(_a[1]))); break;
        case 25: _t->passwordRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: _t->passwordError(); break;
        case 27: _t->toggleReplyMarking(); break;
        case 28: _t->updateReplyMarkingAction(); break;
        case 29: _t->updateReplyMode(); break;
        case 30: _t->markReplyModeHandpicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ComposeWidget::*)(const Common::LogKind , const QString & , const QString & )>(_a, &ComposeWidget::logged, 0))
            return;
    }
}

const QMetaObject *Gui::ComposeWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gui::ComposeWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Gui13ComposeWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Gui::ComposeWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void Gui::ComposeWidget::logged(const Common::LogKind _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
